pub struct CallAssetPayloadDTO {
pub phone_number: String,
pub country_code: String,
pub call_conversion_action: Option<String>,
pub ad_schedule_targets: Vec<AdScheduleTargetDTO>,
pub resource_name: Option<String>,
}Available on crate feature
ad-manager only.Expand description
CallAssetPayloadDTO from the GoHighLevel OpenAPI spec.
Fields
phone_number: StringPhone number for call ads Required by the API.
country_code: StringTwo-letter ISO country code Required by the API.
call_conversion_action: Option<String>Call conversion action resource name
ad_schedule_targets: Vec<AdScheduleTargetDTO>Ad schedule targets restricting when the call asset is shown
resource_name: Option<String>Google Ads resource name for an existing call asset