pub struct ConversionValueSettings {
pub default_value: f64,
pub default_currency_code: String,
pub always_use_default_value: bool,
}Available on crate feature
ad-manager only.Expand description
ConversionValueSettings from the GoHighLevel OpenAPI spec.
Fields
default_value: f64Default monetary value assigned to each conversion Required by the API.
default_currency_code: StringISO 4217 currency code for the default value Required by the API.
always_use_default_value: boolWhen true, always uses the default value even if a transaction-specific value is provided Required by the API.