pub struct BlogPostUpdateResponseWrapperDTO {
pub updated_blog_post: Option<BlogPostResponseDTO>,
}Available on crate feature
blogs only.Expand description
BlogPostUpdateResponseWrapperDTO from the GoHighLevel OpenAPI spec.
Fields
updated_blog_post: Option<BlogPostResponseDTO>Object containing response data of blog post update Required by the API. (Optional here so responses that omit it still parse.)