pub struct CreateBlogPostParams {Show 14 fields
pub title: String,
pub location_id: String,
pub blog_id: String,
pub image_url: String,
pub description: String,
pub raw_html: String,
pub status: String,
pub image_alt_text: String,
pub categories: Vec<String>,
pub tags: Vec<String>,
pub author: String,
pub url_slug: String,
pub canonical_link: Option<String>,
pub published_at: String,
}Available on crate feature
blogs only.Expand description
CreateBlogPostParams from the GoHighLevel OpenAPI spec.
Fields
title: StringRequired by the API.
location_id: StringRequired by the API.
blog_id: StringYou can find the blog id from blog site dashboard link Required by the API.
image_url: StringRequired by the API.
description: StringRequired by the API.
raw_html: StringRequired by the API.
status: StringAllowed values: DRAFT, PUBLISHED, SCHEDULED, ARCHIVED.
Required by the API.
image_alt_text: StringRequired by the API.
categories: Vec<String>This needs to be array of category ids, which you can get from the category get api call. Required by the API.
This needs to be author id, which you can get from the author get api call. Required by the API.
url_slug: StringRequired by the API.
canonical_link: Option<String>published_at: StringProvide ISO timestamp Required by the API.