AppointmentCreateSchema

Struct AppointmentCreateSchema 

pub struct AppointmentCreateSchema {
Show 17 fields pub title: Option<String>, pub meeting_location_type: Option<String>, pub meeting_location_id: Option<String>, pub override_location_config: Option<bool>, pub appointment_status: Option<String>, pub assigned_user_id: Option<String>, pub description: Option<String>, pub address: Option<String>, pub ignore_date_range: Option<bool>, pub to_notify: Option<bool>, pub ignore_free_slot_validation: Option<bool>, pub rrule: Option<String>, pub calendar_id: String, pub location_id: String, pub contact_id: String, pub start_time: String, pub end_time: Option<String>,
}
Available on crate feature calendars only.
AppointmentCreateSchema from the GoHighLevel OpenAPI spec.

Fields

title: Option<String>

Title

meeting_location_type: Option<String>

Meeting location type. - If address is provided in the request body, the meetingLocationType defaults to custom. Allowed values: custom, zoom, gmeet, phone, address, ms_teams, google.

meeting_location_id: Option<String>

The unique identifier for the meeting location. - This value can be found in calendar.locationConfigurationsor calendar.teamMembers[].locationConfigurations

override_location_config: Option<bool>

Flag to override location config - false - If only meetingLocationId is provided - true - If only meetingLocationType is provided

appointment_status: Option<String>

Allowed values: new, confirmed, cancelled, showed, noshow, invalid.

assigned_user_id: Option<String>

Assigned User Id

description: Option<String>

Appointment Description

address: Option<String>

Appointment Address

ignore_date_range: Option<bool>

If set to true, the minimum scheduling notice and date range would be ignored

to_notify: Option<bool>

If set to false, the automations will not run

ignore_free_slot_validation: Option<bool>

If true the time slot validation would be avoided for any appointment creation (even the ignoreDateRange)

rrule: Option<String>

RRULE as per the iCalendar (RFC 5545) specification for recurring events. DTSTART is not required, instance ids are calculated on the basis of startTime of the event. The rrule only be applied if ignoreFreeSlotValidation is true.

calendar_id: String

Calendar Id Required by the API.

location_id: String

Location Id Required by the API.

contact_id: String

Contact Id Required by the API.

start_time: String

Start Time Required by the API.

end_time: Option<String>

End Time