CalendarCreateDTO

Struct CalendarCreateDTO 

pub struct CalendarCreateDTO {
Show 55 fields pub is_active: Option<bool>, pub notifications: Vec<CalendarNotification>, pub location_id: String, pub group_id: Option<String>, pub team_members: Vec<TeamMember>, pub event_type: Option<String>, pub name: String, pub description: Option<String>, pub slug: Option<String>, pub widget_slug: Option<String>, pub calendar_type: Option<String>, pub widget_type: Option<String>, pub event_title: Option<String>, pub event_color: Option<String>, pub meeting_location: Option<String>, pub location_configurations: Vec<LocationConfiguration>, pub slot_duration: Option<f64>, pub slot_duration_unit: Option<String>, pub slot_interval: Option<f64>, pub slot_interval_unit: Option<String>, pub slot_buffer: Option<f64>, pub slot_buffer_unit: Option<String>, pub pre_buffer: Option<f64>, pub pre_buffer_unit: Option<String>, pub appoinment_per_slot: Option<f64>, pub appoinment_per_day: Option<f64>, pub allow_booking_after: Option<f64>, pub allow_booking_after_unit: Option<String>, pub allow_booking_for: Option<f64>, pub allow_booking_for_unit: Option<String>, pub open_hours: Vec<OpenHour>, pub enable_recurring: Option<bool>, pub recurring: Option<Recurring>, pub form_id: Option<String>, pub sticky_contact: Option<bool>, pub is_live_payment_mode: Option<bool>, pub auto_confirm: Option<bool>, pub should_send_alert_emails_to_assigned_member: Option<bool>, pub alert_email: Option<String>, pub google_invitation_emails: Option<bool>, pub allow_reschedule: Option<bool>, pub allow_cancellation: Option<bool>, pub should_assign_contact_to_team_member: Option<bool>, pub should_skip_assigning_contact_for_existing: Option<bool>, pub notes: Option<String>, pub pixel_id: Option<String>, pub form_submit_type: Option<String>, pub form_submit_redirect_url: Option<String>, pub form_submit_thanks_message: Option<String>, pub availability_type: Option<String>, pub availabilities: Vec<Availability>, pub guest_type: Option<String>, pub consent_label: Option<String>, pub calendar_cover_image: Option<String>, pub look_busy_config: Option<LookBusyConfiguration>,
}
Available on crate feature calendars only.
CalendarCreateDTO from the GoHighLevel OpenAPI spec.

Fields

is_active: Option<bool>

Should the created calendar be active or draft

notifications: Vec<CalendarNotification>

🚨 Deprecated! Please use ‘Calendar Notifications APIs’ instead.

location_id: String

Required by the API.

group_id: Option<String>

Group Id

team_members: Vec<TeamMember>

Team members are required for calendars of type: Round Robin, Collective, Class, Service. Personal calendar must have exactly one team member.

event_type: Option<String>

Allowed values: RoundRobin_OptimizeForAvailability, RoundRobin_OptimizeForEqualDistribution.

name: String

Required by the API.

description: Option<String>slug: Option<String>widget_slug: Option<String>calendar_type: Option<String>

Allowed values: round_robin, event, class_booking, collective, service_booking, personal.

widget_type: Option<String>

Calendar widget type. Choose “default” for “neo” and “classic” for “classic” layout. Allowed values: default, classic.

event_title: Option<String>event_color: Option<String>meeting_location: Option<String>

🚨 Deprecated! Use locationConfigurations.location or teamMembers[].locationConfigurations.location instead.

location_configurations: Vec<LocationConfiguration>

Meeting location configuration for event calendar

slot_duration: Option<f64>

This controls the duration of the meeting

slot_duration_unit: Option<String>

Unit for slot duration. Allowed values: mins, hours.

slot_interval: Option<f64>

Slot interval reflects the amount of time the between booking slots that will be shown in the calendar.

slot_interval_unit: Option<String>

Unit for slot interval. Allowed values: mins, hours.

slot_buffer: Option<f64>

Slot-Buffer is additional time that can be added after an appointment, allowing for extra time to wrap up

slot_buffer_unit: Option<String>

Unit for slot buffer. Allowed values: mins, hours.

pre_buffer: Option<f64>

Pre-Buffer is additional time that can be added before an appointment, allowing for extra time to get ready

pre_buffer_unit: Option<String>

Unit for pre-buffer. Allowed values: mins, hours.

appoinment_per_slot: Option<f64>

Maximum bookings per slot (per user). Maximum seats per slot in case of Class Booking Calendar.

appoinment_per_day: Option<f64>

Number of appointments that can be booked for a given day

allow_booking_after: Option<f64>

Minimum scheduling notice for events

allow_booking_after_unit: Option<String>

Unit for minimum scheduling notice Allowed values: hours, days, weeks, months.

allow_booking_for: Option<f64>

Minimum number of days/weeks/months for which to allow booking events

allow_booking_for_unit: Option<String>

Unit for controlling the duration for which booking would be allowed for Allowed values: days, weeks, months.

open_hours: Vec<OpenHour>

This is only to set the standard availability. For custom availability, use the availabilities property

enable_recurring: Option<bool>

Enable recurring appointments for the calendars. Please note that only one member should be added in the calendar to enable this

recurring: Option<Recurring>form_id: Option<String>sticky_contact: Option<bool>is_live_payment_mode: Option<bool>auto_confirm: Option<bool>should_send_alert_emails_to_assigned_member: Option<bool>alert_email: Option<String>google_invitation_emails: Option<bool>allow_reschedule: Option<bool>allow_cancellation: Option<bool>should_assign_contact_to_team_member: Option<bool>should_skip_assigning_contact_for_existing: Option<bool>notes: Option<String>pixel_id: Option<String>form_submit_type: Option<String>

Allowed values: RedirectURL, ThankYouMessage.

form_submit_redirect_url: Option<String>form_submit_thanks_message: Option<String>availability_type: Option<String>

Determines which availability type to consider: - 1: Only custom availabilities will be used. - 0: Only open hours will be used. - null: Both custom availabilities and open hours will be considered. Allowed values: 0, 1.

availabilities: Vec<Availability>

This is only to set the custom availability. For standard availability, use the openHours property

guest_type: Option<String>

Allowed values: count_only, collect_detail.

consent_label: Option<String>calendar_cover_image: Option<String>look_busy_config: Option<LookBusyConfiguration>

Look Busy Configuration