pub struct CalendarNotification {
pub type_: Option<String>,
pub should_send_to_contact: Option<bool>,
pub should_send_to_guest: Option<bool>,
pub should_send_to_user: Option<bool>,
pub should_send_to_selected_users: Option<bool>,
pub selected_users: Option<String>,
}Available on crate feature
calendars only.Expand description
CalendarNotification from the GoHighLevel OpenAPI spec.
Fields
type_: Option<String>Calendar Notification
Allowed values: email.
should_send_to_contact: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
should_send_to_guest: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
should_send_to_user: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
should_send_to_selected_users: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
selected_users: Option<String>Comma separated emails Required by the API. (Optional here so responses that omit it still parse.)