pub struct LookBusyConfiguration {
pub enabled: Option<bool>,
pub look_busy_percentage: Option<f64>,
}Available on crate feature
calendars only.Expand description
LookBusyConfiguration from the GoHighLevel OpenAPI spec.
Fields
enabled: Option<bool>Apply Look Busy Required by the API. (Optional here so responses that omit it still parse.)
look_busy_percentage: Option<f64>Percentage of slots that will be hidden Required by the API. (Optional here so responses that omit it still parse.)