pub struct Recurring {
pub freq: Option<String>,
pub count: Option<f64>,
pub booking_option: Option<String>,
pub booking_overlap_default_status: Option<String>,
}Available on crate feature
calendars only.Expand description
Recurring from the GoHighLevel OpenAPI spec.
Fields
freq: Option<String>Allowed values: DAILY, WEEKLY, MONTHLY.
count: Option<f64>Number of recurrences
booking_option: Option<String>This setting contols what to do incase a recurring slot is unavailable
Allowed values: skip, continue, book_next.
booking_overlap_default_status: Option<String>This setting contols what to do incase a recurring slot is unavailable
Allowed values: confirmed, new.