pub struct ForwardConfigDto {
pub is_forwarded: bool,
pub forward_whole_thread: Option<bool>,
pub message_id: Option<String>,
pub email_message_id: Option<String>,
pub source_contact_id: Option<String>,
pub source_conversation_id: Option<String>,
pub to_email: Option<String>,
pub recipient_contact_id: Option<String>,
pub recipient_conversation_id: Option<String>,
}Available on crate feature
conversations only.Expand description
ForwardConfigDto from the GoHighLevel OpenAPI spec.
Fields
is_forwarded: boolSpecify if this is a forwarded email Required by the API.
forward_whole_thread: Option<bool>Specify if forwarding the whole thread or just a single email
message_id: Option<String>Message ID of the email thread being forwarded (source) - REQUIRED for forwarding
email_message_id: Option<String>Email Message ID of the specific email being forwarded (source) - Required for single email forward, ignored for thread forward
source_contact_id: Option<String>Contact ID where the forwarded email originated from (source) - Auto-populated if not provided
source_conversation_id: Option<String>Conversation ID where the forwarded email originated from (source) - Auto-populated if not provided
to_email: Option<String>Email address to forward to (destination)
recipient_contact_id: Option<String>Contact ID of recipient when forwarding (destination)
recipient_conversation_id: Option<String>Conversation ID of recipient when forwarding (destination)