GetEmailMessageResponseDto

Struct GetEmailMessageResponseDto 

pub struct GetEmailMessageResponseDto {
Show 21 fields pub id: Option<String>, pub alt_id: Option<String>, pub thread_id: Option<String>, pub location_id: Option<String>, pub contact_id: Option<String>, pub conversation_id: Option<String>, pub date_added: Option<String>, pub subject: Option<String>, pub body: Option<String>, pub direction: Option<String>, pub status: Option<String>, pub content_type: Option<String>, pub attachments: Vec<String>, pub provider: Option<String>, pub from_: Option<String>, pub to: Vec<String>, pub cc: Vec<String>, pub bcc: Vec<String>, pub reply_to_message_id: Option<String>, pub source: Option<String>, pub conversation_provider_id: Option<String>,
}
Available on crate feature conversations only.
GetEmailMessageResponseDto from the GoHighLevel OpenAPI spec.

Fields

id: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

alt_id: Option<String>

External Id

thread_id: Option<String>

Message Id or thread Id Required by the API. (Optional here so responses that omit it still parse.)

location_id: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

contact_id: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

conversation_id: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

date_added: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

subject: Option<String>body: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

direction: Option<String>

Allowed values: inbound, outbound. Required by the API. (Optional here so responses that omit it still parse.)

status: Option<String>

Allowed values: pending, scheduled, sent, delivered, read, undelivered, connected, failed, opened.

content_type: Option<String>

Required by the API. (Optional here so responses that omit it still parse.)

attachments: Vec<String>

An array of attachment URLs.

provider: Option<String>from_: Option<String>

Name and Email Id of the sender Required by the API. (Optional here so responses that omit it still parse.)

to: Vec<String>

List of email Ids of the receivers Required by the API. (Optional here so responses that omit it still parse.)

cc: Vec<String>

List of email Ids of the people in the cc field

bcc: Vec<String>

List of email Ids of the people in the bcc field

reply_to_message_id: Option<String>

In case of reply, email message Id of the reply to email

source: Option<String>

Email source Allowed values: workflow, bulk_actions, campaign, api, app.

conversation_provider_id: Option<String>

Conversation provider ID