pub struct GetMessageResponseDto {Show 17 fields
pub id: Option<String>,
pub type_: Option<f64>,
pub message_type: Option<String>,
pub location_id: Option<String>,
pub contact_id: Option<String>,
pub conversation_id: Option<String>,
pub date_added: Option<String>,
pub body: Option<String>,
pub direction: Option<String>,
pub status: Option<String>,
pub content_type: Option<String>,
pub attachments: Vec<String>,
pub meta: Option<MessageMeta>,
pub source: Option<String>,
pub user_id: Option<String>,
pub conversation_provider_id: Option<String>,
pub chat_widget_id: Option<String>,
}conversations only.Expand description
GetMessageResponseDto from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
type_: Option<f64>Required by the API. (Optional here so responses that omit it still parse.)
message_type: Option<String>Type of the message as a string
Allowed values: TYPE_CALL, TYPE_SMS, TYPE_RCS, TYPE_EMAIL,
TYPE_SMS_REVIEW_REQUEST, TYPE_WEBCHAT, TYPE_SMS_NO_SHOW_REQUEST,
TYPE_CAMPAIGN_SMS, TYPE_CAMPAIGN_CALL, TYPE_CAMPAIGN_EMAIL,
TYPE_CAMPAIGN_VOICEMAIL, TYPE_FACEBOOK.
Required by the API.
(Optional here so responses that omit it still parse.)
location_id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
contact_id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
conversation_id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
date_added: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
body: Option<String>direction: Option<String>Allowed values: inbound, outbound.
Required by the API.
(Optional here so responses that omit it still parse.)
status: Option<String>Allowed values: connected, delivered, failed, opened, pending, read,
scheduled, sent, undelivered, clicked, opt_out, queued.
content_type: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
attachments: Vec<String>An array of attachment URLs. Attachments will be empty for Call and Voicemails, type 1 and 10. Please use get call recording API to fetch call recording and voicemails.
meta: Option<MessageMeta>source: Option<String>Message source
Allowed values: workflow, bulk_actions, campaign, api, app.
user_id: Option<String>User Id
conversation_provider_id: Option<String>Conversation Provider Id
chat_widget_id: Option<String>Chat Widget Id