pub struct ProcessMessageResponseDto {
pub success: Option<bool>,
pub conversation_id: Option<String>,
pub message_id: Option<String>,
pub message: Option<String>,
pub contact_id: Option<String>,
pub date_added: Option<String>,
pub email_message_id: Option<String>,
}Available on crate feature
conversations only.Expand description
ProcessMessageResponseDto from the GoHighLevel OpenAPI spec.
Fields
success: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
conversation_id: Option<String>Conversation ID. Required by the API. (Optional here so responses that omit it still parse.)
message_id: Option<String>This is the main Message ID Required by the API. (Optional here so responses that omit it still parse.)
message: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
contact_id: Option<String>date_added: Option<String>Format: date-time (ISO-8601 string).
email_message_id: Option<String>Trait Implementations
Sourceimpl Clone for ProcessMessageResponseDto
impl Clone for ProcessMessageResponseDto
Sourcefn clone(&self) -> ProcessMessageResponseDto
fn clone(&self) -> ProcessMessageResponseDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessMessageResponseDto
impl Debug for ProcessMessageResponseDto
Sourceimpl Default for ProcessMessageResponseDto
impl Default for ProcessMessageResponseDto
Sourcefn default() -> ProcessMessageResponseDto
fn default() -> ProcessMessageResponseDto
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProcessMessageResponseDto
impl<'de> Deserialize<'de> for ProcessMessageResponseDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more