pub struct SendMessageResponseDto {
pub conversation_id: Option<String>,
pub email_message_id: Option<String>,
pub message_id: Option<String>,
pub message_ids: Vec<String>,
pub msg: Option<String>,
pub forward_data: Option<ForwardResponseDto>,
pub status: Option<String>,
}Available on crate feature
conversations only.Expand description
SendMessageResponseDto from the GoHighLevel OpenAPI spec.
Fields
conversation_id: Option<String>Conversation ID. Required by the API. (Optional here so responses that omit it still parse.)
email_message_id: Option<String>This contains the email message id (only for Email type). Use this ID to send inbound replies to GHL to create a threaded email.
message_id: Option<String>This is the main Message ID Required by the API. (Optional here so responses that omit it still parse.)
message_ids: Vec<String>When sending via the GMB channel, we will be returning list of messageIds instead of
single messageId.
msg: Option<String>Additional response message when sending a workflow message
forward_data: Option<ForwardResponseDto>Optional metadata for forwarded email
status: Option<String>Message status
Allowed values: delivered, failed, pending, read.
Required by the API.
(Optional here so responses that omit it still parse.)