ICustomField

Struct ICustomField 

pub struct ICustomField {
Show 16 fields pub location_id: Option<String>, pub name: Option<String>, pub description: Option<String>, pub placeholder: Option<String>, pub show_in_forms: Option<bool>, pub options: Vec<OptionDTO>, pub accepted_formats: Option<String>, pub id: Option<String>, pub object_key: Option<String>, pub data_type: Option<String>, pub parent_id: Option<String>, pub field_key: Option<String>, pub allow_custom_option: Option<bool>, pub max_file_limit: Option<f64>, pub date_added: Option<String>, pub date_updated: Option<String>,
}
Available on crate feature custom-fields only.
ICustomField from the GoHighLevel OpenAPI spec.

Fields

location_id: Option<String>

Location Id Required by the API. (Optional here so responses that omit it still parse.)

name: Option<String>

Field name

description: Option<String>

Description of the field

placeholder: Option<String>

Placeholder text for the field

show_in_forms: Option<bool>

Whether the field should be shown in forms Required by the API. (Optional here so responses that omit it still parse.)

options: Vec<OptionDTO>

Options for the field (Optional, valid only for SINGLE_OPTIONS, MULTIPLE_OPTIONS, RADIO, CHECKBOX, TEXTBOX_LIST type)

accepted_formats: Option<String>

Allowed file formats for uploads. Options include: .pdf, .docx, .doc, .jpg, .jpeg, .png, .gif, .csv, .xlsx, .xls, all Allowed values: .pdf, .docx, .doc, .jpg, .jpeg, .png, .gif, .csv, .xlsx, .xls, all.

id: Option<String>

Unique identifier of the object Required by the API. (Optional here so responses that omit it still parse.)

object_key: Option<String>

The key for your custom / standard object. This key uniquely identifies the custom object. Example: “custom_object.pet” for a custom object related to pets. Required by the API. (Optional here so responses that omit it still parse.)

data_type: Option<String>

Type of field that you are trying to create Allowed values: TEXT, LARGE_TEXT, NUMERICAL, PHONE, MONETORY, CHECKBOX, SINGLE_OPTIONS, MULTIPLE_OPTIONS, DATE, TEXTBOX_LIST, FILE_UPLOAD, RADIO. Required by the API. (Optional here so responses that omit it still parse.)

parent_id: Option<String>

ID of the parent folder Required by the API. (Optional here so responses that omit it still parse.)

field_key: Option<String>

Field key. For Custom Object it’s formatted as “custom_object.{objectKey}.{fieldKey}”. “custom_object” is a fixed prefix, “{objectKey}” is your custom object’s identifier, and “{fieldName}” is the unique field name within that object. Example: “custom_object.pet.name” for a “name” field in a “pet” custom object. Required by the API. (Optional here so responses that omit it still parse.)

allow_custom_option: Option<bool>

Determines if users can add a custom option value different from the predefined options in records for RADIO type fields. A custom value added in one record does not automatically become an option and will not appear as an option for other records.

max_file_limit: Option<f64>

Maximum file limit for uploads

date_added: Option<String>

Date and time when the object was added Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)

date_updated: Option<String>

Date and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)