pub struct ICustomFieldFolder {
pub id: Option<String>,
pub object_key: Option<String>,
pub location_id: Option<String>,
pub name: Option<String>,
}Available on crate feature
custom-fields only.Expand description
ICustomFieldFolder from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Unique identifier of the object Required by the API. (Optional here so responses that omit it still parse.)
object_key: Option<String>The key for your custom object. This key uniquely identifies the custom object. Example: “custom_object.pet” for a custom object related to pets. Required by the API. (Optional here so responses that omit it still parse.)
location_id: Option<String>Location Id Required by the API. (Optional here so responses that omit it still parse.)
name: Option<String>Field name Required by the API. (Optional here so responses that omit it still parse.)