Module knowledge_base

Module knowledge_base 

Available on crate feature knowledge-base only.
knowledge_base models (38 schemas). knowledge-base data models for GoHighLevel API V2 (38 types).

Generated from HighLevel’s official OpenAPI spec for the Knowledge Base module. Every endpoint that uses these types, with its parameters, required scopes and enum values, is documented in the knowledge-base API reference.

Enable with features = ["knowledge-base"].

Structs

AddFaqDTO
AddFaqDTO from the GoHighLevel OpenAPI spec.
BadRequestDTO
BadRequestDTO from the GoHighLevel OpenAPI spec.
CrawledUrlDTO
CrawledUrlDTO from the GoHighLevel OpenAPI spec.
CrawlingAggregateDTO
CrawlingAggregateDTO from the GoHighLevel OpenAPI spec.
CrawlingRecordDTO
CrawlingRecordDTO from the GoHighLevel OpenAPI spec.
CrawlingStatusDataDTO
CrawlingStatusDataDTO from the GoHighLevel OpenAPI spec.
CrawlingStatusResponseDTO
CrawlingStatusResponseDTO from the GoHighLevel OpenAPI spec.
CreateFaqResponseDTO
CreateFaqResponseDTO from the GoHighLevel OpenAPI spec.
CreateKnowledgeBaseDTO
CreateKnowledgeBaseDTO from the GoHighLevel OpenAPI spec.
CreateKnowledgeBaseResponseDTO
CreateKnowledgeBaseResponseDTO from the GoHighLevel OpenAPI spec.
DeleteFaqResponseDTO
DeleteFaqResponseDTO from the GoHighLevel OpenAPI spec.
DeleteKnowledgeBaseResponseDTO
DeleteKnowledgeBaseResponseDTO from the GoHighLevel OpenAPI spec.
DeleteWebsiteUrlRequestDTO
DeleteWebsiteUrlRequestDTO from the GoHighLevel OpenAPI spec.
DeleteWebsiteUrlResponseDTO
DeleteWebsiteUrlResponseDTO from the GoHighLevel OpenAPI spec.
DiscoverWebsiteDataDTO
DiscoverWebsiteDataDTO from the GoHighLevel OpenAPI spec.
DiscoverWebsiteRequestDTO
DiscoverWebsiteRequestDTO from the GoHighLevel OpenAPI spec.
DiscoverWebsiteResponseDTO
DiscoverWebsiteResponseDTO from the GoHighLevel OpenAPI spec.
ErrorDetailsDTO
ErrorDetailsDTO from the GoHighLevel OpenAPI spec.
FaqResponseDTO
FaqResponseDTO from the GoHighLevel OpenAPI spec.
GetAllKnowledgeBasesPaginatedDataDTO
GetAllKnowledgeBasesPaginatedDataDTO from the GoHighLevel OpenAPI spec.
GetAllKnowledgeBasesPaginatedResponseDTO
GetAllKnowledgeBasesPaginatedResponseDTO from the GoHighLevel OpenAPI spec.
GetAllUrlsByKnowledgeBaseResponseDTO
GetAllUrlsByKnowledgeBaseResponseDTO from the GoHighLevel OpenAPI spec.
GetKnowledgeBaseByIdDataDTO
GetKnowledgeBaseByIdDataDTO from the GoHighLevel OpenAPI spec.
GetKnowledgeBaseByIdResponseDTO
GetKnowledgeBaseByIdResponseDTO from the GoHighLevel OpenAPI spec.
InternalServerErrorDTO
InternalServerErrorDTO from the GoHighLevel OpenAPI spec.
KnowledgeBaseDataDTO
KnowledgeBaseDataDTO from the GoHighLevel OpenAPI spec.
KnowledgeBaseListItemDTO
KnowledgeBaseListItemDTO from the GoHighLevel OpenAPI spec.
KnowledgeBaseMetadataDTO
KnowledgeBaseMetadataDTO from the GoHighLevel OpenAPI spec.
ListFaqsResponseDTO
ListFaqsResponseDTO from the GoHighLevel OpenAPI spec.
OperationDetailsDTO
OperationDetailsDTO from the GoHighLevel OpenAPI spec.
TrainDiscoveredUrlsDTO
TrainDiscoveredUrlsDTO from the GoHighLevel OpenAPI spec.
TrainDiscoveredUrlsResponseDTO
TrainDiscoveredUrlsResponseDTO from the GoHighLevel OpenAPI spec.
UnauthorizedDTO
UnauthorizedDTO from the GoHighLevel OpenAPI spec.
UnprocessableDTO
UnprocessableDTO from the GoHighLevel OpenAPI spec.
UpdateFaqBodyDTO
UpdateFaqBodyDTO from the GoHighLevel OpenAPI spec.
UpdateFaqResponseDTO
UpdateFaqResponseDTO from the GoHighLevel OpenAPI spec.
UpdateKnowledgeBaseDTO
UpdateKnowledgeBaseDTO from the GoHighLevel OpenAPI spec.
UpdateKnowledgeBaseResponseDTO
UpdateKnowledgeBaseResponseDTO from the GoHighLevel OpenAPI spec.