pub struct KnowledgeBaseListItemDTO {
pub id: Option<String>,
pub name: Option<String>,
pub created_at: Option<String>,
}Available on crate feature
knowledge-base only.Expand description
KnowledgeBaseListItemDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Knowledge base ID Required by the API. (Optional here so responses that omit it still parse.)
name: Option<String>Knowledge base name Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>Date when knowledge base was created Required by the API. (Optional here so responses that omit it still parse.)