pub struct KnowledgeBaseMetadataDTO {
pub faqs: Option<f64>,
pub urls: Option<f64>,
pub rich_text: Option<f64>,
pub files: Option<f64>,
pub web_searches: Option<f64>,
pub tables: Option<f64>,
}knowledge-base only.Expand description
KnowledgeBaseMetadataDTO from the GoHighLevel OpenAPI spec.
Fields
faqs: Option<f64>Number of FAQs in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)
urls: Option<f64>Number of URLs in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)
rich_text: Option<f64>Number of rich text documents in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)
files: Option<f64>Number of files in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)
web_searches: Option<f64>Number of web searche configs in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)
tables: Option<f64>Number of tables in the knowledge base Required by the API. (Optional here so responses that omit it still parse.)