pub struct UpdateFaqBodyDTO {
pub question: String,
pub answer: String,
}Available on crate feature
knowledge-base only.Expand description
UpdateFaqBodyDTO from the GoHighLevel OpenAPI spec.
Fields
question: Stringfaq question as a string Required by the API.
answer: Stringfaq answer as a string Required by the API.