pub struct UpdateKnowledgeBaseDTO {
pub name: Option<String>,
pub description: Option<String>,
}Available on crate feature
knowledge-base only.Expand description
UpdateKnowledgeBaseDTO from the GoHighLevel OpenAPI spec.
Fields
name: Option<String>field to update the name of the knowledge base
description: Option<String>field to update the description of the knowledge base