pub struct CustomRRulesOptions {
pub interval_type: Option<String>,
pub interval: Option<f64>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub day_of_month: Option<f64>,
pub day_of_week: Option<String>,
pub month_of_year: Option<f64>,
pub count: Option<f64>,
pub create_task_if_over_due: Option<bool>,
pub due_after_seconds: Option<f64>,
}Available on crate feature
locations only.Expand description
CustomRRulesOptions from the GoHighLevel OpenAPI spec.
Fields
interval_type: Option<String>Allowed values: yearly, monthly, weekly, daily, hourly.
Required by the API.
(Optional here so responses that omit it still parse.)
interval: Option<f64>Required by the API. (Optional here so responses that omit it still parse.)
start_date: Option<String>Start Date Required by the API. (Optional here so responses that omit it still parse.)
end_date: Option<String>End Date
day_of_month: Option<f64>1, 2, 3, …, 27, 31
day_of_week: Option<String>Allowed values: MO, TU, WE, TH, FR, SA, SU.
month_of_year: Option<f64>1, 2, ….., 11, 12
count: Option<f64>Max number of task executions
create_task_if_over_due: Option<bool>Create Task If Over Due
due_after_seconds: Option<f64>Due after seconds Required by the API. (Optional here so responses that omit it still parse.)