pub struct MoveOrDeleteObjectParams {
pub alt_type: Option<String>,
pub alt_id: Option<String>,
pub id: Option<String>,
}Available on crate feature
medias only.Expand description
MoveOrDeleteObjectParams from the GoHighLevel OpenAPI spec.
Fields
alt_type: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
alt_id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)