pub struct UploadFileResponseDTO {
pub file_id: Option<String>,
pub url: Option<String>,
}Available on crate feature
medias only.Expand description
UploadFileResponseDTO from the GoHighLevel OpenAPI spec.
Fields
file_id: Option<String>ID of the uploaded file Required by the API. (Optional here so responses that omit it still parse.)
url: Option<String>Google Cloud Storage URL of the uploaded file Required by the API. (Optional here so responses that omit it still parse.)