Module objects

Module objects 

Available on crate feature objects only.
objects models (20 schemas). objects data models for GoHighLevel API V2 (20 types).

Generated from HighLevel’s official OpenAPI spec for the Objects module. Every endpoint that uses these types, with its parameters, required scopes and enum values, is documented in the objects API reference.

Enable with features = ["objects"].

Structs

CreateCustomObjectRecordDto
CreateCustomObjectRecordDto from the GoHighLevel OpenAPI spec.
CreateCustomObjectSchemaDTO
CreateCustomObjectSchemaDTO from the GoHighLevel OpenAPI spec.
CreatedByResponseDTO
CreatedByResponseDTO from the GoHighLevel OpenAPI spec.
CustomObjectByIdResponseDTO
CustomObjectByIdResponseDTO from the GoHighLevel OpenAPI spec.
CustomObjectDisplayPropertyDetails
CustomObjectDisplayPropertyDetails from the GoHighLevel OpenAPI spec.
CustomObjectLabelDto
CustomObjectLabelDto from the GoHighLevel OpenAPI spec.
CustomObjectLabelUpdateDto
CustomObjectLabelUpdateDto from the GoHighLevel OpenAPI spec.
CustomObjectListResponseDTO
CustomObjectListResponseDTO from the GoHighLevel OpenAPI spec.
CustomObjectResponseDTO
CustomObjectResponseDTO from the GoHighLevel OpenAPI spec.
ICustomField
ICustomField from the GoHighLevel OpenAPI spec.
ICustomObjectSchema
ICustomObjectSchema from the GoHighLevel OpenAPI spec.
IRecordSchema
IRecordSchema from the GoHighLevel OpenAPI spec.
ObjectRecordDeleteResponseDTO
ObjectRecordDeleteResponseDTO from the GoHighLevel OpenAPI spec.
OptionDTO
OptionDTO from the GoHighLevel OpenAPI spec.
RecordByIdResponseDTO
RecordByIdResponseDTO from the GoHighLevel OpenAPI spec.
RecordResponseDTO
RecordResponseDTO from the GoHighLevel OpenAPI spec.
SearchRecordResponseDTO
SearchRecordResponseDTO from the GoHighLevel OpenAPI spec.
SearchRecordsBody
SearchRecordsBody from the GoHighLevel OpenAPI spec.
UpdateCustomObjectRecordDto
UpdateCustomObjectRecordDto from the GoHighLevel OpenAPI spec.
UpdateCustomObjectSchemaDTO
UpdateCustomObjectSchemaDTO from the GoHighLevel OpenAPI spec.