pub struct CreateCustomObjectSchemaDTO {
pub labels: CustomObjectLabelDto,
pub key: String,
pub description: Option<String>,
pub location_id: String,
pub primary_display_property_details: CustomObjectDisplayPropertyDetails,
}Available on crate feature
objects only.Expand description
CreateCustomObjectSchemaDTO from the GoHighLevel OpenAPI spec.
Fields
labels: CustomObjectLabelDtoThis is what your custom object will be called. These labels will be used to display your custom object on the UI Required by the API.
key: Stringkey that would be used to refer the Custom Object internally (lowercase + underscore_separated). ‘custom_objects.’ would be added as prefix by default Required by the API.
description: Option<String>Pet Object`s description
location_id: StringLocation Id Required by the API.
primary_display_property_details: CustomObjectDisplayPropertyDetailsPrimary property which will be displayed on the record page Required by the API.