pub struct CustomObjectByIdResponseDTO {
pub object: Option<ICustomObjectSchema>,
pub cache: Option<bool>,
pub fields: Vec<ICustomField>,
}Available on crate feature
objects only.Expand description
CustomObjectByIdResponseDTO from the GoHighLevel OpenAPI spec.
Fields
object: Option<ICustomObjectSchema>cache: Option<bool>Is the response served from cache Required by the API. (Optional here so responses that omit it still parse.)
fields: Vec<ICustomField>Trait Implementations
Sourceimpl Clone for CustomObjectByIdResponseDTO
impl Clone for CustomObjectByIdResponseDTO
Sourcefn clone(&self) -> CustomObjectByIdResponseDTO
fn clone(&self) -> CustomObjectByIdResponseDTO
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomObjectByIdResponseDTO
impl Debug for CustomObjectByIdResponseDTO
Sourceimpl Default for CustomObjectByIdResponseDTO
impl Default for CustomObjectByIdResponseDTO
Sourcefn default() -> CustomObjectByIdResponseDTO
fn default() -> CustomObjectByIdResponseDTO
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CustomObjectByIdResponseDTO
impl<'de> Deserialize<'de> for CustomObjectByIdResponseDTO
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more