pub struct CustomObjectDisplayPropertyDetails {
pub key: String,
pub name: String,
pub data_type: String,
}Available on crate feature
objects only.Expand description
CustomObjectDisplayPropertyDetails from the GoHighLevel OpenAPI spec.
Fields
key: Stringkey that would be used to refer the custom field internally (lowercase + underscore_separated). ‘custom_objects.{{objectKey}}’ would be added as prefix by default is not passed Required by the API.
name: StringName of the Primary property name which will be displayed on the record page Required by the API.
data_type: StringPrimary property data Type (it can either be TEXT or NUMERICAL type) Required by the API.