pub struct IRecordSchema {
pub id: Option<String>,
pub owner: Vec<String>,
pub followers: Vec<String>,
pub properties: Option<String>,
pub date_added: Option<String>,
pub date_updated: Option<String>,
}objects only.Expand description
IRecordSchema from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>id of the record Required by the API. (Optional here so responses that omit it still parse.)
owner: Vec<String>Owner (User’s id). Limited to 1 for now. Only Supported with custom objects Required by the API. (Optional here so responses that omit it still parse.)
followers: Vec<String>Follower (User’s ids). Limited to 10 for now Required by the API. (Optional here so responses that omit it still parse.)
properties: Option<String>Properties of the record Required by the API. (Optional here so responses that omit it still parse.)
date_added: Option<String>Date and time when the object was added Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)
date_updated: Option<String>Date and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)