pub struct RecordResponseDTO {
pub id: String,
pub owner: Vec<String>,
pub followers: Vec<String>,
pub properties: String,
pub created_at: String,
pub updated_at: String,
pub location_id: String,
pub object_id: String,
pub object_key: String,
pub created_by: CreatedByResponseDTO,
pub last_updated_by: CreatedByResponseDTO,
pub search_after: Vec<f64>,
}Available on crate feature
objects only.Expand description
RecordResponseDTO from the GoHighLevel OpenAPI spec.
Fields
id: Stringid of the record Required by the API.
owner: Vec<String>Owner (User’s id). Limited to 1 for now . Only supported for custom objects for now Required by the API.
followers: Vec<String>Follower (User’s ids). Limited to 10 and supported for custom objects for now Required by the API.
properties: StringProperties of the record Required by the API.
created_at: StringDate and time when the object was added Format: date-time (ISO-8601 string). Required by the API.
updated_at: StringDate and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API.
location_id: StringLocation Id Required by the API.
object_id: StringObjectId Id Required by the API.
object_key: StringObjectId key Required by the API.
created_by: CreatedByResponseDTOCreated By Meta Required by the API.
last_updated_by: CreatedByResponseDTOLast Updated By Meta Required by the API.
search_after: Vec<f64>Required by the API.