pub struct SearchRecordsBody {
pub location_id: String,
pub page: f64,
pub page_limit: f64,
pub query: String,
pub search_after: Vec<String>,
}Available on crate feature
objects only.Expand description
SearchRecordsBody from the GoHighLevel OpenAPI spec.
Fields
location_id: StringLocation Id Required by the API.
page: f64Page Required by the API.
page_limit: f64Page Limit Required by the API.
query: StringPass this query parameter to search using your searchable properties. For example, if you have a custom object called “Pets” and have configured “name” as a searchable property, you can pass name:Buddy to search for pets with the name “Buddy.” Required by the API.
search_after: Vec<String>Required by the API.