pub struct UpdateCustomObjectSchemaDTO {
pub labels: Option<CustomObjectLabelUpdateDto>,
pub description: Option<String>,
pub location_id: String,
pub searchable_properties: Vec<String>,
}Available on crate feature
objects only.Expand description
UpdateCustomObjectSchemaDTO from the GoHighLevel OpenAPI spec.
Fields
labels: Option<CustomObjectLabelUpdateDto>This is how your custom object will be displayed
description: Option<String>Pet Object`s description
location_id: Stringlocation id Required by the API.
searchable_properties: Vec<String>Searchable Fields: Provide the field key of your object that you want to search on, using the format (custom_object.<object_name>.<field_key>). Required by the API.