pub struct CreateCustomProvidersResponseSchema {Show 13 fields
pub name: Option<String>,
pub description: Option<String>,
pub payments_url: Option<String>,
pub query_url: Option<String>,
pub image_url: Option<String>,
pub id: Option<String>,
pub location_id: Option<String>,
pub marketplace_app_id: Option<String>,
pub payment_provider: Option<Value>,
pub deleted: Option<bool>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub trace_id: Option<String>,
}payments only.Expand description
CreateCustomProvidersResponseSchema from the GoHighLevel OpenAPI spec.
Fields
name: Option<String>The name of the custom provider Required by the API. (Optional here so responses that omit it still parse.)
description: Option<String>Description of payment gateway. Shown on the payments integrations page as subtext Required by the API. (Optional here so responses that omit it still parse.)
payments_url: Option<String>This url will be loaded in iFrame to start a payment session. Required by the API. (Optional here so responses that omit it still parse.)
query_url: Option<String>The url used for querying payments related events. Ex. verify, refund, subscription etc. Required by the API. (Optional here so responses that omit it still parse.)
image_url: Option<String>Public image url for logo of the payment gateway displayed on the payments integrations page. Required by the API. (Optional here so responses that omit it still parse.)
id: Option<String>The unique identifier for the custom provider. Required by the API. (Optional here so responses that omit it still parse.)
location_id: Option<String>Location id Required by the API. (Optional here so responses that omit it still parse.)
marketplace_app_id: Option<String>The application id of marketplace Required by the API. (Optional here so responses that omit it still parse.)
payment_provider: Option<Value>Payment provider details.
deleted: Option<bool>Whether the config is deleted or not. true represents config is deleted Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>The creation timestamp of the custom provider. Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)
updated_at: Option<String>The last update timestamp of the custom provider. Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)
trace_id: Option<String>Trace id of the custom provider.