pub struct CreateWhiteLabelIntegrationProviderDto {
pub alt_id: String,
pub alt_type: String,
pub unique_name: String,
pub title: String,
pub provider: String,
pub description: String,
pub image_url: String,
}payments only.Expand description
CreateWhiteLabelIntegrationProviderDto from the GoHighLevel OpenAPI spec.
Fields
alt_id: Stringlocation Id / company Id based on altType Required by the API.
alt_type: StringAlt Type
Allowed values: location.
Required by the API.
unique_name: StringA unique name given to the integration provider, uniqueName must start and end with a character. Only lowercase characters and hyphens (-) are supported Required by the API.
title: StringThe title or name of the integration provider. Required by the API.
provider: StringThe type of payment provider associated with the integration provider.
Allowed values: authorize-net, nmi.
Required by the API.
description: StringA brief description providing additional information about the integration provider. Required by the API.
image_url: StringThe URL to an image representing the integration provider. The imageUrl should start with “https://" and ensure that this URL is publicly accessible. Required by the API.