pub struct UpdateCustomProviderCapabilitiesResponseSchema {
pub success: Option<bool>,
}Available on crate feature
payments only.Expand description
UpdateCustomProviderCapabilitiesResponseSchema from the GoHighLevel OpenAPI spec.
Fields
success: Option<bool>Whether the custom provider capabilities are updated or not. true represents capabilities are updated Required by the API. (Optional here so responses that omit it still parse.)