pub struct PostCreateRequest {Show 16 fields
pub account_ids: Vec<String>,
pub summary: Option<String>,
pub media: Vec<PostMediaSchema>,
pub status: Option<Value>,
pub schedule_date: Option<String>,
pub created_by: Option<String>,
pub follow_up_comment: Option<String>,
pub og_tags_details: Option<OgTagsSchema>,
pub type_: Value,
pub post_approval_details: Option<PostApprovalSchema>,
pub schedule_time_updated: Option<bool>,
pub tags: Vec<String>,
pub category_id: Option<String>,
pub tiktok_post_details: Option<TiktokPostSchema>,
pub gmb_post_details: Option<GMBPostSchema>,
pub user_id: Option<String>,
}social-media-posting only.Expand description
PostCreateRequest from the GoHighLevel OpenAPI spec.
Fields
account_ids: Vec<String>Account Ids
summary: Option<String>Post Content The limitations of content as per the platforms is provided through the reference link in API description
media: Vec<PostMediaSchema>Post Media Data The limitations of media as per the platforms is provided through the reference link in API description
status: Option<Value>Status must be one of the following values: in_progress, draft, failed, published, scheduled, in_review, notification_sent, deleted
schedule_date: Option<String>Schedule Date
created_by: Option<String>Created By
follow_up_comment: Option<String>Follow Up Comment on platform. It is not allowed on Tiktok and GMB accounts and there is a limit of 280 charecters for twitter account
Og Tags Meta Data
type_: ValuePost Type must be one of the following values: - post, story, reel Required by the API.
post_approval_details: Option<PostApprovalSchema>Post Approval Details
schedule_time_updated: Option<bool>if schedule datetime is updated
Array of Tag Value
category_id: Option<String>Category Id
tiktok_post_details: Option<TiktokPostSchema>Tiktok Post Details
gmb_post_details: Option<GMBPostSchema>GMB Post Details
user_id: Option<String>User ID