pub struct AvailableShippingRate {
pub name: Option<String>,
pub description: Option<String>,
pub currency: Option<String>,
pub amount: Option<f64>,
pub is_carrier_rate: Option<bool>,
pub shipping_carrier_id: Option<String>,
pub percentage_of_rate_fee: Option<f64>,
pub shipping_carrier_services: Vec<ShippingCarrierServiceDto>,
pub id: Option<String>,
pub shipping_zone_id: Option<String>,
}store only.Expand description
AvailableShippingRate from the GoHighLevel OpenAPI spec.
Fields
name: Option<String>Name of the shipping zone Required by the API. (Optional here so responses that omit it still parse.)
description: Option<String>Delivery description
currency: Option<String>The currency of the amount of the rate / handling fee Required by the API. (Optional here so responses that omit it still parse.)
amount: Option<f64>The amount of the shipping rate if it is normal rate (0 means free ). Fixed Handling fee if it is a carrier rate (it will add to the carrier rate). Required by the API. (Optional here so responses that omit it still parse.)
is_carrier_rate: Option<bool>is this a carrier rate
shipping_carrier_id: Option<String>Shipping carrier id Required by the API. (Optional here so responses that omit it still parse.)
percentage_of_rate_fee: Option<f64>Percentage of rate fee if it is a carrier rate.
shipping_carrier_services: Vec<ShippingCarrierServiceDto>An array of items
id: Option<String>The unique identifier for the product. Required by the API. (Optional here so responses that omit it still parse.)
shipping_zone_id: Option<String>The unique identifier for the shipping zone. Required by the API. (Optional here so responses that omit it still parse.)