pub struct GetStoreSettingResponseDto {
pub status: Option<bool>,
pub message: Option<String>,
pub data: Option<StoreSettingSchema>,
}Available on crate feature
store only.Expand description
GetStoreSettingResponseDto from the GoHighLevel OpenAPI spec.
Fields
status: Option<bool>Status of api action Required by the API. (Optional here so responses that omit it still parse.)
message: Option<String>Success message
data: Option<StoreSettingSchema>Shipping carrier data Required by the API. (Optional here so responses that omit it still parse.)