pub struct CreateUserDto {Show 15 fields
pub company_id: String,
pub first_name: String,
pub last_name: String,
pub email: String,
pub password: String,
pub phone: Option<String>,
pub type_: String,
pub role: String,
pub location_ids: Vec<String>,
pub permissions: Option<PermissionsDto>,
pub scopes: Vec<String>,
pub scopes_assigned_to_only: Vec<String>,
pub profile_photo: Option<String>,
pub twilio_phone: Option<Value>,
pub platform_language: Option<String>,
}users only.Expand description
CreateUserDto from the GoHighLevel OpenAPI spec.
Fields
company_id: StringRequired by the API.
first_name: StringRequired by the API.
last_name: StringRequired by the API.
email: StringRequired by the API.
password: StringRequired by the API.
phone: Option<String>type_: StringRequired by the API.
role: StringRequired by the API.
location_ids: Vec<String>Required by the API.
permissions: Option<PermissionsDto>scopes: Vec<String>Scopes allowed for users. Only scopes that have been passed will be enabled. Note:- If
passed empty all the scopes will be get disabled
Allowed values: campaigns.readonly, campaigns.write, calendars.readonly,
calendars/events.write, calendars/groups.write, calendars.write, contacts.write,
contacts/bulkActions.write, workflows.readonly, workflows.write, triggers.write,
funnels.write.
scopes_assigned_to_only: Vec<String>Assigned Scopes allowed for users. Only scopes that have been passed will be enabled. If
passed empty all the assigned scopes will be get disabled
Allowed values: campaigns.readonly, campaigns.write, calendars.readonly,
calendars/events.write, calendars/groups.write, calendars.write, contacts.write,
contacts/bulkActions.write, workflows.readonly, workflows.write, triggers.write,
funnels.write.
profile_photo: Option<String>twilio_phone: Option<Value>Per-location inbound Twilio number in E.164 format, keyed by location id (Call and Voicemail Inbound Number for direct Twilio, not LC Phone). Replacement semantics: if you send twilioPhone in the request body, the stored map is replaced entirely with this object (not merged). Any location id omitted from the object is removed from the saved map. Omit the twilioPhone property entirely to leave existing numbers unchanged. Send an empty object {} to clear all per-location numbers. To clear a single location only, set that location id to an empty string “”.
platform_language: Option<String>Platform language preference for the user
Allowed values: en_US, es, fr_CA, fr_FR, nl, de, pt_PT, pt_BR, it,
sv, da, fi.