pub struct FilterByEmailDto {
pub company_id: String,
pub emails: String,
pub deleted: Option<bool>,
pub skip: Option<String>,
pub limit: Option<String>,
pub projection: Option<String>,
}Available on crate feature
users only.Expand description
FilterByEmailDto from the GoHighLevel OpenAPI spec.
Fields
company_id: StringCompany ID to filter users Required by the API.
emails: StringComma-separated list of email addresses to filter users Required by the API.
deleted: Option<bool>Filter deleted users
skip: Option<String>No of results to be skipped before returning the result
limit: Option<String>No of results to be limited before returning the result
projection: Option<String>Projection fields to return. Use “all” for all fields, or specify comma-separated field names. Default returns only id and email