pub struct CustomActionHeaderDTO {
pub key: Option<String>,
pub value: Option<String>,
}Available on crate feature
voice-ai only.Expand description
CustomActionHeaderDTO from the GoHighLevel OpenAPI spec.
Fields
key: Option<String>HTTP header name Required by the API. (Optional here so responses that omit it still parse.)
value: Option<String>HTTP header value Required by the API. (Optional here so responses that omit it still parse.)