pub struct WorkflowTriggerParameters {
pub trigger_prompt: Option<String>,
pub trigger_message: Option<String>,
pub workflow_id: Option<String>,
}Available on crate feature
voice-ai only.Expand description
WorkflowTriggerParameters from the GoHighLevel OpenAPI spec.
Fields
trigger_prompt: Option<String>When to trigger this workflow Required by the API. (Optional here so responses that omit it still parse.)
trigger_message: Option<String>Message to tell the caller Required by the API. (Optional here so responses that omit it still parse.)
workflow_id: Option<String>Workflow ID to trigger Required by the API. (Optional here so responses that omit it still parse.)