pub struct CustomQuestionFieldDTO {
pub custom_question_text: String,
pub single_choice_answers: Vec<String>,
}Available on crate feature
ad-publishing only.Expand description
CustomQuestionFieldDTO from the GoHighLevel OpenAPI spec.
Fields
custom_question_text: StringCustom question text shown to the user Required by the API.
single_choice_answers: Vec<String>Answer choices for the custom question Required by the API.