CreateOrUpdateServiceBookingResponseDTO

Struct CreateOrUpdateServiceBookingResponseDTO 

pub struct CreateOrUpdateServiceBookingResponseDTO {
Show 16 fields pub booking_id: Option<String>, pub location_id: Option<String>, pub contact_id: Option<String>, pub service_location_id: Option<String>, pub title: Option<String>, pub start_time: Option<String>, pub end_time: Option<String>, pub services: Vec<ServiceDTO>, pub timezone: Option<String>, pub status: Option<String>, pub deleted: Option<bool>, pub date_added: Option<String>, pub date_updated: Option<String>, pub created_by: Option<CreatedOrUpdatedBy>, pub meeting_location: Option<String>, pub messages: Vec<Vec<Value>>,
}
Available on crate feature calendars only.
CreateOrUpdateServiceBookingResponseDTO from the GoHighLevel OpenAPI spec.

Fields

booking_id: Option<String>

Booking ID Required by the API. (Optional here so responses that omit it still parse.)

location_id: Option<String>

Location ID Required by the API. (Optional here so responses that omit it still parse.)

contact_id: Option<String>

Contact ID Required by the API. (Optional here so responses that omit it still parse.)

service_location_id: Option<String>

Service Location ID Required by the API. (Optional here so responses that omit it still parse.)

title: Option<String>

Service Booking Title Required by the API. (Optional here so responses that omit it still parse.)

start_time: Option<String>

Start Time Required by the API. (Optional here so responses that omit it still parse.)

end_time: Option<String>

End Time Required by the API. (Optional here so responses that omit it still parse.)

services: Vec<ServiceDTO>

Services Required by the API. (Optional here so responses that omit it still parse.)

timezone: Option<String>

Timezone Required by the API. (Optional here so responses that omit it still parse.)

status: Option<String>

Status Required by the API. (Optional here so responses that omit it still parse.)

deleted: Option<bool>

Tells if the booking is deleted Required by the API. (Optional here so responses that omit it still parse.)

date_added: Option<String>

Date Added Required by the API. (Optional here so responses that omit it still parse.)

date_updated: Option<String>

Date Updated Required by the API. (Optional here so responses that omit it still parse.)

created_by: Option<CreatedOrUpdatedBy>

Booking booked by metadata Required by the API. (Optional here so responses that omit it still parse.)

meeting_location: Option<String>

Meeting Location (If service location is an ask the booker, then the meeting location is used for the booking)

messages: Vec<Vec<Value>>

Optional informative or warning messages (e.g. meeting location ignored for non-ask-booker locations)