pub struct CreateServiceDTO {Show 18 fields
pub location_id: String,
pub name: String,
pub slug: String,
pub staff: Vec<StaffDTO>,
pub description: Option<String>,
pub event_color: Option<String>,
pub cover_image: Option<String>,
pub service_category_id: Option<String>,
pub payment: Option<PaymentDTO>,
pub service_duration: Option<f64>,
pub service_duration_unit: Option<String>,
pub pre_buffer: Option<f64>,
pub pre_buffer_unit: Option<String>,
pub post_buffer: Option<f64>,
pub post_buffer_unit: Option<String>,
pub is_private: Option<bool>,
pub form_id: Option<String>,
pub variations: Vec<CreateServiceVariationDTO>,
}calendars only.Expand description
CreateServiceDTO from the GoHighLevel OpenAPI spec.
Fields
location_id: StringLocation ID Required by the API.
name: StringService name Required by the API.
slug: StringUnique URL-friendly identifier Required by the API.
staff: Vec<StaffDTO>Assigned staff members (at least one required) Required by the API.
description: Option<String>Service description
event_color: Option<String>Service event color (hex)
cover_image: Option<String>Service cover image URL
service_category_id: Option<String>Service category ID (uses default category if not provided)
payment: Option<PaymentDTO>Payment details (default amount is 0, currency configured in Service Global Settings is used.)
service_duration: Option<f64>This controls the duration of the appointment
service_duration_unit: Option<String>Duration unit
Allowed values: mins, hours.
pre_buffer: Option<f64>Pre-Buffer is additional time that can be added before an appointment, allowing for extra time to get ready
pre_buffer_unit: Option<String>Pre-buffer unit
Allowed values: mins, hours.
post_buffer: Option<f64>Post-buffer: Additional time that can be added after an appointment, allowing for extra time to wrap up
post_buffer_unit: Option<String>Post-buffer unit
Allowed values: mins, hours.
is_private: Option<bool>Whether service is private (not shown publicly)
form_id: Option<String>Custom form ID (will be used to display the custom form on the booking page, if only one service is selected)
variations: Vec<CreateServiceVariationDTO>Service variations (pass empty array for no variations)