pub struct ServiceBookingQueryDTO {
pub override_availability: Option<bool>,
pub skip_scheduling_notice: Option<bool>,
}Available on crate feature
calendars only.Expand description
ServiceBookingQueryDTO from the GoHighLevel OpenAPI spec.
Fields
override_availability: Option<bool>If true the time slot validation would be avoided for any booking creation/update (even the skipSchedulingNotice)
skip_scheduling_notice: Option<bool>If set to true, the minimum scheduling notice and date range would be ignored