pub struct ServiceDTO {
pub id: Option<String>,
pub service_category_id: Option<String>,
pub service_staff_id: Option<String>,
pub service_start_time: Option<String>,
pub service_end_time: Option<String>,
pub service_resources: Vec<ServiceResourceDTO>,
pub service_add_ons: Vec<ServiceAddOnResponseDTO>,
}Available on crate feature
calendars only.Expand description
ServiceDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Service ID Required by the API. (Optional here so responses that omit it still parse.)
service_category_id: Option<String>Service Category ID Required by the API. (Optional here so responses that omit it still parse.)
service_staff_id: Option<String>Service Staff ID Required by the API. (Optional here so responses that omit it still parse.)
service_start_time: Option<String>Service Start Time Required by the API. (Optional here so responses that omit it still parse.)
service_end_time: Option<String>Service End Time Required by the API. (Optional here so responses that omit it still parse.)
service_resources: Vec<ServiceResourceDTO>Service Resources
service_add_ons: Vec<ServiceAddOnResponseDTO>Service Add-ons