pub struct ServiceResponseDTO {Show 19 fields
pub id: Option<String>,
pub location_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub slug: Option<String>,
pub event_color: Option<String>,
pub cover_image: Option<String>,
pub service_category_id: Option<String>,
pub payment: Option<PaymentDTO>,
pub service_duration: Option<f64>,
pub service_duration_unit: Option<String>,
pub pre_buffer: Option<f64>,
pub pre_buffer_unit: Option<String>,
pub post_buffer: Option<f64>,
pub post_buffer_unit: Option<String>,
pub is_private: Option<bool>,
pub form_id: Option<String>,
pub variations: Vec<ServiceVariationDTO>,
pub staff: Vec<StaffDTO>,
}calendars only.Expand description
ServiceResponseDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Service ID Required by the API. (Optional here so responses that omit it still parse.)
location_id: Option<String>Location ID Required by the API. (Optional here so responses that omit it still parse.)
name: Option<String>Service name Required by the API. (Optional here so responses that omit it still parse.)
description: Option<String>Service description
slug: Option<String>Unique URL-friendly identifier
event_color: Option<String>Service event color (hex)
cover_image: Option<String>Service cover image URL
service_category_id: Option<String>Service category ID
payment: Option<PaymentDTO>Payment details
service_duration: Option<f64>This controls the duration of the appointment
service_duration_unit: Option<String>Duration unit
Allowed values: mins, hours.
pre_buffer: Option<f64>Pre-Buffer is additional time that can be added before an appointment, allowing for extra time to get ready
pre_buffer_unit: Option<String>Pre-buffer unit
Allowed values: mins, hours.
post_buffer: Option<f64>Post-buffer: Additional time that can be added after an appointment, allowing for extra time to wrap up
post_buffer_unit: Option<String>Post-buffer unit
Allowed values: mins, hours.
is_private: Option<bool>Whether service is private (not shown publicly)
form_id: Option<String>Custom form ID (will be used to display the custom form on the booking page, if only one service is selected)
variations: Vec<ServiceVariationDTO>Service variations
staff: Vec<StaffDTO>Assigned staff members