pub struct UpdateServiceVariationDTO {
pub service_duration: Option<f64>,
pub service_duration_unit: Option<String>,
pub pre_buffer: Option<f64>,
pub pre_buffer_unit: Option<String>,
pub post_buffer: Option<f64>,
pub post_buffer_unit: Option<String>,
pub payment: Option<PaymentDTO>,
pub id: Option<String>,
pub name: Option<String>,
}Available on crate feature
calendars only.Expand description
UpdateServiceVariationDTO from the GoHighLevel OpenAPI spec.
Fields
service_duration: Option<f64>This controls the duration of the appointment
service_duration_unit: Option<String>Duration unit
Allowed values: mins, hours.
pre_buffer: Option<f64>Pre-Buffer is additional time that can be added before an appointment, allowing for extra time to get ready
pre_buffer_unit: Option<String>Pre-buffer unit
Allowed values: mins, hours.
post_buffer: Option<f64>Post-buffer: Additional time that can be added after an appointment, allowing for extra time to wrap up
post_buffer_unit: Option<String>Post-buffer unit
Allowed values: mins, hours.
payment: Option<PaymentDTO>Payment details
id: Option<String>Variation ID
name: Option<String>Variation name