WidgetSettingsDTO

Struct WidgetSettingsDTO 

pub struct WidgetSettingsDTO {
Show 46 fields pub acknowledgement_details: Option<AcknowledgementDetailsDTO>, pub agency_name: Option<String>, pub agency_website: Option<String>, pub allow_avatar_image: Option<bool>, pub auto_country_code: Option<bool>, pub country_code: Option<String>, pub chat_type: String, pub prompt_type: Option<String>, pub chat_icon: String, pub enable_revisit_message: Option<bool>, pub heading: Option<String>, pub legal_msg: Option<String>, pub live_chat_ack_msg: Option<String>, pub live_chat_ended_msg: Option<String>, pub live_chat_feedback_msg: Option<String>, pub live_chat_feedback_note: Option<String>, pub live_chat_intro_msg: Option<String>, pub live_chat_user_inactive_msg: Option<String>, pub live_chat_user_inactive_time: Option<String>, pub live_chat_visitor_inactive_msg: Option<String>, pub live_chat_visitor_inactive_time: Option<String>, pub locale: Option<String>, pub prompt_avatar: Option<String>, pub prompt_avatar_alt_text: Option<String>, pub is_prompt_avatar_image_optimize: Option<bool>, pub prompt_msg: Option<String>, pub revisit_prompt_msg: Option<String>, pub send_action_text: Option<String>, pub show_agency_branding: Option<bool>, pub show_consent_checkbox: Option<bool>, pub show_live_chat_welcome_msg: Option<bool>, pub show_prompt: Option<bool>, pub sub_heading: Option<String>, pub success_msg: Option<String>, pub support_contact: Option<String>, pub thank_you_msg: Option<String>, pub theme: Option<WidgetSettingsThemeDTO>, pub use_email_field: Option<bool>, pub wa_number: Option<String>, pub widget_primary_color: Option<String>, pub representative_assigned_message: Option<String>, pub dimensions: Option<WidgetSettingsCustomizationDTO>, pub advance_settings: Option<AdvanceSettingsDTO>, pub location_country_code: Option<String>, pub widget_id: Option<String>, pub widget_placement: Option<String>,
}
Available on crate feature chat-widget only.
WidgetSettingsDTO from the GoHighLevel OpenAPI spec.

Fields

acknowledgement_details: Option<AcknowledgementDetailsDTO>

Acknowledgement Details

agency_name: Option<String>

Name of the agency

agency_website: Option<String>

Website URL of the agency

allow_avatar_image: Option<bool>

Allow avatar image

auto_country_code: Option<bool>

Boolean indicating whether to automatically detect country code

country_code: Option<String>

Country code

chat_type: String

Chat Type Required by the API.

prompt_type: Option<String>

Prompt Type

chat_icon: String

Message Chat Circle Required by the API.

enable_revisit_message: Option<bool>

Boolean indicating whether to enable a revisit message

heading: Option<String>

Heading text

legal_msg: Option<String>

Legal message

live_chat_ack_msg: Option<String>

Message acknowledging a live chat

live_chat_ended_msg: Option<String>

Message indicating the end of a live chat

live_chat_feedback_msg: Option<String>

Message asking for feedback after a live chat

live_chat_feedback_note: Option<String>

Note regarding live chat feedback

live_chat_intro_msg: Option<String>

Introduction message for a live chat

live_chat_user_inactive_msg: Option<String>

Message for inactive users during a live chat

live_chat_user_inactive_time: Option<String>

Time for considering a user inactive during a live chat

live_chat_visitor_inactive_msg: Option<String>

Message for inactive visitors during a live chat

live_chat_visitor_inactive_time: Option<String>

Time for considering a visitor inactive during a live chat

locale: Option<String>

Locale setting

prompt_avatar: Option<String>

Avatar for prompts

prompt_avatar_alt_text: Option<String>

Prompt Avatar Alt Text

is_prompt_avatar_image_optimize: Option<bool>

Avatar Image Optimization

prompt_msg: Option<String>

Prompt message

revisit_prompt_msg: Option<String>

Message for revisiting prompts

send_action_text: Option<String>

Text for send action

show_agency_branding: Option<bool>

Boolean indicating whether to show agency branding

show_consent_checkbox: Option<bool>

Boolean indicating whether to show a consent checkbox

show_live_chat_welcome_msg: Option<bool>

Boolean indicating whether to show a welcome message for live chat

show_prompt: Option<bool>

Boolean indicating whether to show prompts

sub_heading: Option<String>

Subheading text

success_msg: Option<String>

Success message

support_contact: Option<String>

Contact information for support

thank_you_msg: Option<String>

Thank you message

theme: Option<WidgetSettingsThemeDTO>

Theme

use_email_field: Option<bool>

Boolean indicating whether to use an email field

wa_number: Option<String>

WhatsApp number

widget_primary_color: Option<String>

Primary color for the widget

representative_assigned_message: Option<String>

Representative Assigned Message

dimensions: Option<WidgetSettingsCustomizationDTO>

Customizations

advance_settings: Option<AdvanceSettingsDTO>

Advance Settings

location_country_code: Option<String>

Location Country Code

widget_id: Option<String>

Widget Id

widget_placement: Option<String>

Widget Placement