ProcessMessageBodyDto

Struct ProcessMessageBodyDto 

pub struct ProcessMessageBodyDto {
Show 17 fields pub type_: String, pub attachments: Vec<String>, pub message: Option<String>, pub conversation_id: String, pub contact_id: String, pub conversation_provider_id: String, pub html: Option<String>, pub subject: Option<String>, pub email_from: Option<String>, pub email_to: Option<String>, pub email_cc: Vec<String>, pub email_bcc: Vec<String>, pub email_message_id: Option<String>, pub alt_id: Option<String>, pub direction: Option<Value>, pub date: Option<String>, pub call: Option<CallDataDTO>,
}
Available on crate feature conversations only.
ProcessMessageBodyDto from the GoHighLevel OpenAPI spec.

Fields

type_: String

Message Type Allowed values: SMS, RCS, Email, WhatsApp, GMB, IG, FB, Custom, WebChat, Live_Chat, Call, IVR_Call. Required by the API.

attachments: Vec<String>

Array of attachments

message: Option<String>

Message Body

conversation_id: String

Conversation Id Required by the API.

contact_id: String

Contact Id Required by the API.

conversation_provider_id: String

Conversation Provider Id Required by the API.

html: Option<String>

HTML Body of Email

subject: Option<String>

Subject of the Email

email_from: Option<String>

Email address to send from. This field is associated with the contact record and cannot be dynamically changed.

email_to: Option<String>

Recipient email address. This field is associated with the contact record and cannot be dynamically changed.

email_cc: Vec<String>

List of email address to CC

email_bcc: Vec<String>

List of email address to BCC

email_message_id: Option<String>

Send the email message id for which this email should be threaded. This is for replying to a specific email

alt_id: Option<String>

external mail provider’s message id

direction: Option<Value>

Message direction, if required can be set manually, default is outbound

date: Option<String>

Date of the inbound message Format: date-time (ISO-8601 string).

call: Option<CallDataDTO>

Phone call dialer and receiver information