pub struct ProcessMessageResponseDto {
pub success: bool,
pub conversation_id: String,
pub message_id: String,
pub message: String,
pub contact_id: Option<String>,
pub date_added: Option<String>,
pub email_message_id: Option<String>,
}Available on crate feature
conversations only.Expand description
ProcessMessageResponseDto from the GoHighLevel OpenAPI spec.
Fields
success: boolWhether the message processing succeeded Required by the API.
conversation_id: StringConversation ID. Required by the API.
message_id: StringThis is the main Message ID Required by the API.
message: StringResult message returned after processing Required by the API.
contact_id: Option<String>Contact ID associated with the processed message
date_added: Option<String>Timestamp when the processed message was created Format: date-time (ISO-8601 string).
email_message_id: Option<String>Email message ID created for email conversations