pub struct SendMessageBodyDto {Show 25 fields
pub type_: String,
pub sub_type: Value,
pub contact_id: String,
pub appointment_id: Option<String>,
pub attachments: Vec<String>,
pub email_from: Option<String>,
pub email_cc: Vec<String>,
pub email_bcc: Vec<String>,
pub html: Option<String>,
pub message: Option<String>,
pub subject: Option<String>,
pub reply_message_id: Option<String>,
pub template_id: Option<String>,
pub thread_id: Option<String>,
pub scheduled_timestamp: Option<f64>,
pub conversation_provider_id: Option<String>,
pub email_to: Option<String>,
pub custom_subtype_id: Option<String>,
pub email_reply_mode: Option<String>,
pub from_number: Option<String>,
pub to_number: Option<String>,
pub forward: Option<ForwardConfigDto>,
pub status: String,
pub uses_native_scheduling_ai: Option<bool>,
pub optimization_period: Option<String>,
}conversations only.Expand description
SendMessageBodyDto from the GoHighLevel OpenAPI spec.
Fields
type_: StringType of message being sent
Allowed values: SMS, RCS, Email, WhatsApp, IG, FB, Custom, Live_Chat,
TIKTOK.
Required by the API.
sub_type: ValueType of message being sent Required by the API.
contact_id: StringID of the contact receiving the message Required by the API.
appointment_id: Option<String>ID of the associated appointment
attachments: Vec<String>Array of attachment URLs
email_from: Option<String>Email address to send from
email_cc: Vec<String>Array of CC email addresses
email_bcc: Vec<String>Array of BCC email addresses
html: Option<String>HTML content of the message
message: Option<String>Text content of the message
subject: Option<String>Subject line for email messages
reply_message_id: Option<String>ID of message being replied to
template_id: Option<String>ID of message template
thread_id: Option<String>ID of message thread. For email messages, this is the message ID that contains multiple email messages in the thread
scheduled_timestamp: Option<f64>UTC Timestamp (in seconds) at which the message should be scheduled
conversation_provider_id: Option<String>ID of conversation provider
email_to: Option<String>Email address to send to, if different from contact’s primary email. This should be a valid email address associated with the contact.
custom_subtype_id: Option<String>Custom subtype ID for email unsubscription preferences. Only applies to email messages.
email_reply_mode: Option<String>Mode for email replies
Allowed values: reply, reply_all.
from_number: Option<String>Phone number used as the sender number for outbound messages
to_number: Option<String>Recipient phone number for outbound messages
forward: Option<ForwardConfigDto>Forwarding configuration for emails
status: StringMessage status
Allowed values: delivered, failed, pending, read.
Required by the API.
uses_native_scheduling_ai: Option<bool>Whether the scheduled email uses native AI for the email scheduling
optimization_period: Option<String>Optimization period in hours (24h, 48h, or 72h)
Allowed values: 24h, 48h, 72h.