pub struct UploadFilesErrorResponseDto {
pub status: Option<String>,
pub message: Option<String>,
}Available on crate feature
conversations only.Expand description
UploadFilesErrorResponseDto from the GoHighLevel OpenAPI spec.
Fields
status: Option<String>HTTP Status code of the request
Allowed values: 400, 413, 415.
Required by the API.
(Optional here so responses that omit it still parse.)
message: Option<String>Error message of the request Required by the API. (Optional here so responses that omit it still parse.)