pub struct CustomFolderDeleteResponseDto {
pub succeded: Option<bool>,
pub id: Option<String>,
pub key: Option<String>,
}Available on crate feature
custom-fields only.Expand description
CustomFolderDeleteResponseDto from the GoHighLevel OpenAPI spec.
Fields
succeded: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
id: Option<String>Required by the API. (Optional here so responses that omit it still parse.)
key: Option<String>Required by the API. (Optional here so responses that omit it still parse.)