pub struct CreateCustomMenuDTO {
pub title: String,
pub url: String,
pub icon: IconSchema,
pub show_on_company: bool,
pub show_on_location: bool,
pub show_to_all_locations: bool,
pub open_mode: String,
pub locations: Vec<String>,
pub user_role: String,
pub allow_camera: Option<bool>,
pub allow_microphone: Option<bool>,
}custom-menus only.Expand description
CreateCustomMenuDTO from the GoHighLevel OpenAPI spec.
Fields
title: StringTitle of the custom menu Required by the API.
url: StringURL of the custom menu Required by the API.
icon: IconSchemaIcon information for the custom menu Required by the API.
show_on_company: boolWhether the menu must be displayed on the agency’s level Required by the API.
show_on_location: boolWhether the menu must be displayed for sub-accounts level Required by the API.
show_to_all_locations: boolWhether the menu must be displayed to all sub-accounts Required by the API.
open_mode: StringMode for opening the menu link
Allowed values: iframe, new_tab, current_tab.
Required by the API.
locations: Vec<String>List of sub-account IDs where the menu should be shown. This list is applicable only when showOnLocation is true and showToAllLocations is false Required by the API.
user_role: StringWhich user-roles should the menu be accessible to?
Allowed values: all, admin, user.
Required by the API.
allow_camera: Option<bool>Whether to allow camera access (only for iframe mode)
allow_microphone: Option<bool>Whether to allow microphone access (only for iframe mode)