pub struct CustomMenuSchema {Show 13 fields
pub id: Option<String>,
pub icon: Option<IconSchemaOptional>,
pub title: Option<String>,
pub url: Option<String>,
pub order: Option<f64>,
pub show_on_company: Option<bool>,
pub show_on_location: Option<bool>,
pub show_to_all_locations: Option<bool>,
pub locations: Vec<String>,
pub open_mode: Option<String>,
pub user_role: Option<String>,
pub allow_camera: Option<bool>,
pub allow_microphone: Option<bool>,
}custom-menus only.Expand description
CustomMenuSchema from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Unique identifier for the custom menu
icon: Option<IconSchemaOptional>Icon information for the menu item
title: Option<String>Title of the custom menu
url: Option<String>URL of the custom menu
order: Option<f64>Order of the custom menu
show_on_company: Option<bool>Filter to show only agency-level menu links. When omitted, fetches both agency and sub-account menu links. Ignored if locationId is provided
show_on_location: Option<bool>Whether the menu must be displayed for sub-accounts level
show_to_all_locations: Option<bool>Whether the menu must be displayed to all sub-accounts
locations: Vec<String>List of sub-account IDs where the menu should be shown. This list is applicable only when showOnLocation is true and showToAllLocations is false
open_mode: Option<String>Mode for opening the menu link
Allowed values: iframe, new_tab, current_tab.
user_role: Option<String>Which user-roles should the menu be accessible to?
Allowed values: all, admin, user.
allow_camera: Option<bool>Indicates if camera access is allowed for this menu
allow_microphone: Option<bool>Indicates if microphone access is allowed for this menu