UpdateCustomMenuDTO

Struct UpdateCustomMenuDTO 

pub struct UpdateCustomMenuDTO {
    pub title: Option<String>,
    pub url: Option<String>,
    pub icon: Option<IconSchemaOptional>,
    pub show_on_company: Option<bool>,
    pub show_on_location: Option<bool>,
    pub show_to_all_locations: Option<bool>,
    pub open_mode: Option<String>,
    pub locations: Vec<String>,
    pub user_role: Option<String>,
    pub allow_camera: Option<bool>,
    pub allow_microphone: Option<bool>,
}
Available on crate feature custom-menus only.
UpdateCustomMenuDTO from the GoHighLevel OpenAPI spec.

Fields

title: Option<String>

Title of the custom menu

url: Option<String>

URL of the custom menu

icon: Option<IconSchemaOptional>

Icon information for the custom menu

show_on_company: Option<bool>

Whether the menu must be displayed on the agency’s level

show_on_location: Option<bool>

Whether the menu must be displayed for sub-accounts level

show_to_all_locations: Option<bool>

Whether the menu must be displayed to all sub-accounts

open_mode: Option<String>

Mode for opening the menu link Allowed values: iframe, new_tab, current_tab.

locations: Vec<String>

List of sub-account IDs where the menu should be shown. This list is applicable only when showOnLocation is true and showToAllLocations is false

user_role: Option<String>

Which user-roles should the menu be accessible to? Allowed values: all, admin, user.

allow_camera: Option<bool>

Whether to allow camera access (only for iframe mode)

allow_microphone: Option<bool>

Whether to allow microphone access (only for iframe mode)