pub struct AddFaqDTO {
pub location_id: String,
pub question: String,
pub answer: String,
pub knowledge_base_id: String,
}Available on crate feature
knowledge-base only.Expand description
AddFaqDTO from the GoHighLevel OpenAPI spec.
Fields
location_id: Stringlocation ID as string Required by the API.
question: Stringfaq question as a string Required by the API.
answer: Stringfaq answer as a string Required by the API.
knowledge_base_id: Stringknowledge base ID as string Required by the API.