pub struct GetAllKnowledgeBasesPaginatedDataDTO {
pub knowledge_bases: Vec<KnowledgeBaseListItemDTO>,
pub active_count: Option<f64>,
pub has_more: Option<bool>,
pub last_knowledge_base_id: Option<String>,
}Available on crate feature
knowledge-base only.Expand description
GetAllKnowledgeBasesPaginatedDataDTO from the GoHighLevel OpenAPI spec.
Fields
knowledge_bases: Vec<KnowledgeBaseListItemDTO>Array of knowledge bases Required by the API. (Optional here so responses that omit it still parse.)
active_count: Option<f64>Total count of all active knowledge bases Required by the API. (Optional here so responses that omit it still parse.)
has_more: Option<bool>Whether there are more knowledge bases available Required by the API. (Optional here so responses that omit it still parse.)
last_knowledge_base_id: Option<String>ID of the last knowledge base in this page (use for next page request)