KnowledgeBaseDataDTO

Struct KnowledgeBaseDataDTO 

pub struct KnowledgeBaseDataDTO {
    pub id: Option<String>,
    pub name: Option<String>,
    pub name_lower_case: Option<String>,
    pub location_id: Option<String>,
    pub kb_metadata: Option<Value>,
    pub deleted: Option<bool>,
    pub created_at: Option<String>,
    pub updated_at: Option<String>,
}
Available on crate feature knowledge-base only.
KnowledgeBaseDataDTO from the GoHighLevel OpenAPI spec.

Fields

id: Option<String>

Knowledge base ID Required by the API. (Optional here so responses that omit it still parse.)

name: Option<String>

Knowledge base name Required by the API. (Optional here so responses that omit it still parse.)

name_lower_case: Option<String>

Knowledge base name in lowercase Required by the API. (Optional here so responses that omit it still parse.)

location_id: Option<String>

Location ID Required by the API. (Optional here so responses that omit it still parse.)

kb_metadata: Option<Value>

Knowledge base metadata Required by the API. (Optional here so responses that omit it still parse.)

deleted: Option<bool>

Whether the knowledge base is deleted Required by the API. (Optional here so responses that omit it still parse.)

created_at: Option<String>

Date when knowledge base was created Required by the API. (Optional here so responses that omit it still parse.)

updated_at: Option<String>

Date when knowledge base was last updated Required by the API. (Optional here so responses that omit it still parse.)