pub struct KnowledgeBaseMetadataDTO {
pub faqs: f64,
pub urls: f64,
pub rich_text: f64,
pub files: f64,
pub web_searches: f64,
pub tables: f64,
}Available on crate feature
knowledge-base only.Expand description
KnowledgeBaseMetadataDTO from the GoHighLevel OpenAPI spec.
Fields
faqs: f64Number of FAQs in the knowledge base Required by the API.
urls: f64Number of URLs in the knowledge base Required by the API.
rich_text: f64Number of rich text documents in the knowledge base Required by the API.
files: f64Number of files in the knowledge base Required by the API.
web_searches: f64Number of web searche configs in the knowledge base Required by the API.
tables: f64Number of tables in the knowledge base Required by the API.