pub struct RecurringTaskResponseDTO {
pub id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub location_id: Option<String>,
pub updated_at: Option<String>,
pub created_at: Option<String>,
pub rrule_options: Option<CustomRRulesOptions>,
pub total_occurrence: Option<f64>,
pub deleted: Option<bool>,
pub assigned_to: Option<String>,
pub contact_id: Option<String>,
}locations only.Expand description
RecurringTaskResponseDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>Recurring Task Id Required by the API. (Optional here so responses that omit it still parse.)
title: Option<String>Name of the task Required by the API. (Optional here so responses that omit it still parse.)
description: Option<String>Description of the task Required by the API. (Optional here so responses that omit it still parse.)
location_id: Option<String>Location Id Required by the API. (Optional here so responses that omit it still parse.)
updated_at: Option<String>Updated At Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>Created At Required by the API. (Optional here so responses that omit it still parse.)
rrule_options: Option<CustomRRulesOptions>Recurring rules Required by the API. (Optional here so responses that omit it still parse.)
total_occurrence: Option<f64>Total Occurrence Required by the API. (Optional here so responses that omit it still parse.)
deleted: Option<bool>Deleted Required by the API. (Optional here so responses that omit it still parse.)
assigned_to: Option<String>Assigned To
contact_id: Option<String>Contact Id