pub struct UpdateObject {
pub name: String,
pub alt_type: String,
pub alt_id: String,
}Available on crate feature
medias only.Expand description
UpdateObject from the GoHighLevel OpenAPI spec.
Fields
name: StringNew name for the file or folder Required by the API.
alt_type: StringType of entity that owns the file or folder
Allowed values: location.
Required by the API.
alt_id: StringLocation identifier that owns the file or folder Required by the API.