pub struct CreatedByResponseDTO {
pub channel: Option<String>,
pub created_at: Option<String>,
pub source: Option<String>,
pub source_id: Option<String>,
}Available on crate feature
objects only.Expand description
CreatedByResponseDTO from the GoHighLevel OpenAPI spec.
Fields
channel: Option<String>Creation Channel Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>Created At Required by the API. (Optional here so responses that omit it still parse.)
source: Option<String>From where the record was created Required by the API. (Optional here so responses that omit it still parse.)
source_id: Option<String>User/Resource Id Required by the API. (Optional here so responses that omit it still parse.)