ICustomObjectSchema

Struct ICustomObjectSchema 

pub struct ICustomObjectSchema {
    pub id: Option<String>,
    pub standard: Option<bool>,
    pub key: Option<String>,
    pub labels: Option<CustomObjectLabelDto>,
    pub description: Option<String>,
    pub location_id: Option<String>,
    pub primary_display_property: Option<String>,
    pub date_added: Option<String>,
    pub date_updated: Option<String>,
    pub type_: Option<Value>,
}
Available on crate feature objects only.
ICustomObjectSchema from the GoHighLevel OpenAPI spec.

Fields

id: Option<String>

id of the custom / standard object schema Required by the API. (Optional here so responses that omit it still parse.)

standard: Option<bool>

false in case of custom objects and true in case of standard objects like contacts and opportunities Required by the API. (Optional here so responses that omit it still parse.)

key: Option<String>

key that would be used to refer the custom / standard Object internally (lowercase + underscore_separated). For custom objects, ‘custom_objects.’ would be added as prefix by default Required by the API. (Optional here so responses that omit it still parse.)

labels: Option<CustomObjectLabelDto>

This is what your custom / standard object will be called. These labels will be used to display your custom object on the UI Required by the API. (Optional here so responses that omit it still parse.)

description: Option<String>

Custom / Standard Object Descriptions for example , Pet Object`s description

location_id: Option<String>

location’s id Required by the API. (Optional here so responses that omit it still parse.)

primary_display_property: Option<String>

Primary property for the custom / standard Object. This would be used as primary data when rendering the UI. ‘custom_objects.{{object_key}} or business.{{object_key}} (for company)’ would be added as prefix by default for all the custom / standard objects Required by the API. (Optional here so responses that omit it still parse.)

date_added: Option<String>

Date and time when the object was added Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)

date_updated: Option<String>

Date and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)

type_: Option<Value>

Object`s Type