pub struct RecordResponseDTO {
pub id: Option<String>,
pub owner: Vec<String>,
pub followers: Vec<String>,
pub properties: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub location_id: Option<String>,
pub object_id: Option<String>,
pub object_key: Option<String>,
pub created_by: Option<CreatedByResponseDTO>,
pub last_updated_by: Option<CreatedByResponseDTO>,
pub search_after: Vec<f64>,
}objects only.Expand description
RecordResponseDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>id of the record Required by the API. (Optional here so responses that omit it still parse.)
owner: Vec<String>Owner (User’s id). Limited to 1 for now . Only supported for custom objects for now Required by the API. (Optional here so responses that omit it still parse.)
followers: Vec<String>Follower (User’s ids). Limited to 10 and supported for custom objects for now Required by the API. (Optional here so responses that omit it still parse.)
properties: Option<String>Properties of the record Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>Date and time when the object was added Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)
updated_at: Option<String>Date and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API. (Optional here so responses that omit it still parse.)
location_id: Option<String>Location Id Required by the API. (Optional here so responses that omit it still parse.)
object_id: Option<String>ObjectId Id Required by the API. (Optional here so responses that omit it still parse.)
object_key: Option<String>ObjectId key Required by the API. (Optional here so responses that omit it still parse.)
created_by: Option<CreatedByResponseDTO>Created By Meta Required by the API. (Optional here so responses that omit it still parse.)
last_updated_by: Option<CreatedByResponseDTO>Last Updated By Meta Required by the API. (Optional here so responses that omit it still parse.)
search_after: Vec<f64>Required by the API. (Optional here so responses that omit it still parse.)