pub struct CSVFileRequiredBadRequestDTO {
pub status: Option<f64>,
pub options: Option<Value>,
pub message: Option<String>,
pub name: Option<String>,
pub error: Option<String>,
pub status_code: Option<f64>,
pub trace_id: Option<String>,
}Available on crate feature
social-planner only.Expand description
CSVFileRequiredBadRequestDTO from the GoHighLevel OpenAPI spec.
Fields
status: Option<f64>HTTP Status Required by the API. (Optional here so responses that omit it still parse.)
options: Option<Value>Options
message: Option<String>Error message Required by the API. (Optional here so responses that omit it still parse.)
name: Option<String>Exception name Required by the API. (Optional here so responses that omit it still parse.)
error: Option<String>Error type Required by the API. (Optional here so responses that omit it still parse.)
status_code: Option<f64>HTTP Status Code Required by the API. (Optional here so responses that omit it still parse.)
trace_id: Option<String>Trace ID for debugging