pub struct WrappedCreateCategoryQueueResponseDTO {
pub success: Option<bool>,
pub status_code: Option<f64>,
pub results: Option<CreateCategoryQueueResponseDTO>,
pub trace_id: Option<String>,
}Available on crate feature
social-planner only.Expand description
WrappedCreateCategoryQueueResponseDTO from the GoHighLevel OpenAPI spec.
Fields
success: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
status_code: Option<f64>Required by the API. (Optional here so responses that omit it still parse.)
results: Option<CreateCategoryQueueResponseDTO>Required by the API. (Optional here so responses that omit it still parse.)
trace_id: Option<String>Trait Implementations
Sourceimpl Clone for WrappedCreateCategoryQueueResponseDTO
impl Clone for WrappedCreateCategoryQueueResponseDTO
Sourcefn clone(&self) -> WrappedCreateCategoryQueueResponseDTO
fn clone(&self) -> WrappedCreateCategoryQueueResponseDTO
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for WrappedCreateCategoryQueueResponseDTO
impl Default for WrappedCreateCategoryQueueResponseDTO
Sourcefn default() -> WrappedCreateCategoryQueueResponseDTO
fn default() -> WrappedCreateCategoryQueueResponseDTO
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WrappedCreateCategoryQueueResponseDTO
impl<'de> Deserialize<'de> for WrappedCreateCategoryQueueResponseDTO
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more