pub struct WrappedCreateQueueItemResponseDTO {
pub success: Option<bool>,
pub status_code: Option<f64>,
pub results: Option<CreateQueueItemResponseDTO>,
pub trace_id: Option<String>,
}Available on crate feature
social-planner only.Expand description
WrappedCreateQueueItemResponseDTO from the GoHighLevel OpenAPI spec.
Fields
success: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
status_code: Option<f64>Required by the API. (Optional here so responses that omit it still parse.)
results: Option<CreateQueueItemResponseDTO>Required by the API. (Optional here so responses that omit it still parse.)
trace_id: Option<String>Trait Implementations
Sourceimpl Clone for WrappedCreateQueueItemResponseDTO
impl Clone for WrappedCreateQueueItemResponseDTO
Sourcefn clone(&self) -> WrappedCreateQueueItemResponseDTO
fn clone(&self) -> WrappedCreateQueueItemResponseDTO
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for WrappedCreateQueueItemResponseDTO
impl Default for WrappedCreateQueueItemResponseDTO
Sourcefn default() -> WrappedCreateQueueItemResponseDTO
fn default() -> WrappedCreateQueueItemResponseDTO
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WrappedCreateQueueItemResponseDTO
impl<'de> Deserialize<'de> for WrappedCreateQueueItemResponseDTO
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more