pub struct WrappedFetchQueueByIdResponseDTO {
pub success: Option<bool>,
pub status_code: Option<f64>,
pub results: Option<FetchQueueByIdResponseDTO>,
pub trace_id: Option<String>,
}Available on crate feature
social-planner only.Expand description
WrappedFetchQueueByIdResponseDTO from the GoHighLevel OpenAPI spec.
Fields
success: Option<bool>Required by the API. (Optional here so responses that omit it still parse.)
status_code: Option<f64>Required by the API. (Optional here so responses that omit it still parse.)
results: Option<FetchQueueByIdResponseDTO>Required by the API. (Optional here so responses that omit it still parse.)
trace_id: Option<String>Trait Implementations
Sourceimpl Clone for WrappedFetchQueueByIdResponseDTO
impl Clone for WrappedFetchQueueByIdResponseDTO
Sourcefn clone(&self) -> WrappedFetchQueueByIdResponseDTO
fn clone(&self) -> WrappedFetchQueueByIdResponseDTO
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for WrappedFetchQueueByIdResponseDTO
impl Default for WrappedFetchQueueByIdResponseDTO
Sourcefn default() -> WrappedFetchQueueByIdResponseDTO
fn default() -> WrappedFetchQueueByIdResponseDTO
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WrappedFetchQueueByIdResponseDTO
impl<'de> Deserialize<'de> for WrappedFetchQueueByIdResponseDTO
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more