pub struct StoreOrderNotificationDto {
pub enabled: Option<bool>,
pub subject: Option<String>,
pub email_template_id: Option<String>,
pub default_email_template_id: Option<String>,
}Available on crate feature
store only.Expand description
StoreOrderNotificationDto from the GoHighLevel OpenAPI spec.
Fields
enabled: Option<bool>Store order notification enabled Required by the API. (Optional here so responses that omit it still parse.)
subject: Option<String>Store order email subject Required by the API. (Optional here so responses that omit it still parse.)
email_template_id: Option<String>Email Template Id Required by the API. (Optional here so responses that omit it still parse.)
default_email_template_id: Option<String>Default Email Template Id Required by the API. (Optional here so responses that omit it still parse.)