pub struct StoreSettingSchema {
pub alt_id: Option<String>,
pub alt_type: Option<String>,
pub shipping_origin: Option<StoreShippingOriginDto>,
pub store_order_notification: Option<StoreOrderNotificationDto>,
pub store_order_fulfillment_notification: Option<StoreOrderFulfillmentNotificationDto>,
pub id: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
}Available on crate feature
store only.Expand description
StoreSettingSchema from the GoHighLevel OpenAPI spec.
Fields
alt_id: Option<String>Location Id or Agency Id Required by the API. (Optional here so responses that omit it still parse.)
alt_type: Option<String>Allowed values: location.
Required by the API.
(Optional here so responses that omit it still parse.)
shipping_origin: Option<StoreShippingOriginDto>Shipping origin address Required by the API. (Optional here so responses that omit it still parse.)
store_order_notification: Option<StoreOrderNotificationDto>Store order notification email
store_order_fulfillment_notification: Option<StoreOrderFulfillmentNotificationDto>Store order fulfillment notification email
id: Option<String>The unique identifier for the settings. Required by the API. (Optional here so responses that omit it still parse.)
created_at: Option<String>created at Required by the API. (Optional here so responses that omit it still parse.)
updated_at: Option<String>updated at Required by the API. (Optional here so responses that omit it still parse.)