pub struct SendPostCallNotificationDTO {
pub admins: bool,
pub all_users: bool,
pub contact_assigned_user: bool,
pub specific_users: Vec<String>,
pub custom_emails: Vec<String>,
}Available on crate feature
voice-ai only.Expand description
SendPostCallNotificationDTO from the GoHighLevel OpenAPI spec.
Fields
admins: boolEnables post-call notifications to all admin users in the location. Default: true Required by the API.
all_users: boolEnables post-call notifications to all users in the location. Default: false Required by the API.
contact_assigned_user: boolEnables post-call notifications to the user assigned to the contact. Default: false Required by the API.
specific_users: Vec<String>Array of specific user IDs to receive post-call notifications. Default: [] Required by the API.
custom_emails: Vec<String>Array of custom email addresses to receive post-call notifications. Default: [] Required by the API.