pub struct CreateCalendarResourceDTO {
pub location_id: String,
pub name: String,
pub description: String,
pub quantity: f64,
pub out_of_service: f64,
pub capacity: f64,
pub calendar_ids: Vec<String>,
}Available on crate feature
calendars only.Expand description
CreateCalendarResourceDTO from the GoHighLevel OpenAPI spec.
Fields
location_id: StringRequired by the API.
name: StringRequired by the API.
description: StringRequired by the API.
quantity: f64Quantity of the equipment. Required by the API.
out_of_service: f64Quantity of the out of service equipment. Required by the API.
capacity: f64Capacity of the room. Required by the API.
calendar_ids: Vec<String>Service calendar IDs to be mapped with the resource. One equipment can only be mapped with one service calendar. One room can be mapped with multiple service calendars. Required by the API.