pub struct CreateCustomFieldsDTO {Show 13 fields
pub location_id: String,
pub name: Option<String>,
pub description: Option<String>,
pub placeholder: Option<String>,
pub show_in_forms: bool,
pub options: Vec<OptionDTO>,
pub accepted_formats: Option<String>,
pub data_type: String,
pub field_key: String,
pub object_key: String,
pub max_file_limit: Option<f64>,
pub allow_custom_option: Option<bool>,
pub parent_id: String,
}custom-fields only.Expand description
CreateCustomFieldsDTO from the GoHighLevel OpenAPI spec.
Fields
location_id: StringLocation Id Required by the API.
name: Option<String>Field name
description: Option<String>Description of the field
placeholder: Option<String>Placeholder text for the field
show_in_forms: boolWhether the field should be shown in forms Required by the API.
options: Vec<OptionDTO>Options for the field (Optional, valid only for SINGLE_OPTIONS, MULTIPLE_OPTIONS, RADIO, CHECKBOX, TEXTBOX_LIST type)
accepted_formats: Option<String>Allowed file formats for uploads. Options include: .pdf, .docx, .doc, .jpg, .jpeg, .png,
.gif, .csv, .xlsx, .xls, all
Allowed values: .pdf, .docx, .doc, .jpg, .jpeg, .png, .gif, .csv,
.xlsx, .xls, all.
data_type: StringType of field that you are trying to create
Allowed values: TEXT, LARGE_TEXT, NUMERICAL, PHONE, MONETORY, CHECKBOX,
SINGLE_OPTIONS, MULTIPLE_OPTIONS, DATE, TEXTBOX_LIST, FILE_UPLOAD, RADIO.
Required by the API.
field_key: StringField key. For Custom Object it’s formatted as “custom_object.{objectKey}.{fieldKey}”. “custom_object” is a fixed prefix, “{objectKey}” is your custom object’s identifier, and “{fieldKey}” is the unique field name within that object. Example: “custom_object.pet.name” for a “name” field in a “pet” custom object. Required by the API.
object_key: StringThe key for your custom object. This key uniquely identifies the custom object. Example: “custom_object.pet” for a custom object related to pets. Required by the API.
max_file_limit: Option<f64>Maximum file limit for uploads. Applicable only for fields with a data type of FILE_UPLOAD.
allow_custom_option: Option<bool>Determines if users can add a custom option value different from the predefined options in records for RADIO type fields. A custom value added in one record does not automatically become an option and will not appear as an option for other records.
parent_id: StringID of the parent folder Required by the API.