pub struct GetKnowledgeBaseByIdDataDTO {
pub id: String,
pub name: String,
pub name_lower_case: String,
pub location_id: String,
pub deleted: bool,
pub created_at: String,
pub updated_at: String,
pub kb_metadata: KnowledgeBaseMetadataDTO,
pub is_default: Option<bool>,
}Available on crate feature
knowledge-base only.Expand description
GetKnowledgeBaseByIdDataDTO from the GoHighLevel OpenAPI spec.
Fields
id: StringKnowledge base ID Required by the API.
name: StringKnowledge base name Required by the API.
name_lower_case: StringKnowledge base name in lowercase Required by the API.
location_id: StringLocation ID Required by the API.
deleted: boolWhether the knowledge base is deleted Required by the API.
created_at: StringDate when knowledge base was created Required by the API.
updated_at: StringDate when knowledge base was last updated Required by the API.
kb_metadata: KnowledgeBaseMetadataDTOKnowledge base metadata with content counts Required by the API.
is_default: Option<bool>Whether the knowledge base is default or not