ICustomObjectSchema

Struct ICustomObjectSchema 

pub struct ICustomObjectSchema {
    pub id: String,
    pub standard: bool,
    pub key: String,
    pub labels: CustomObjectLabelDto,
    pub description: Option<String>,
    pub location_id: String,
    pub primary_display_property: String,
    pub date_added: String,
    pub date_updated: String,
    pub type_: Option<Value>,
}
Available on crate feature objects only.
ICustomObjectSchema from the GoHighLevel OpenAPI spec.

Fields

id: String

id of the custom / standard object schema Required by the API.

standard: bool

false in case of custom objects and true in case of standard objects like contacts and opportunities Required by the API.

key: String

key that would be used to refer the custom / standard Object internally (lowercase + underscore_separated). For custom objects, ‘custom_objects.’ would be added as prefix by default Required by the API.

labels: CustomObjectLabelDto

This is what your custom / standard object will be called. These labels will be used to display your custom object on the UI Required by the API.

description: Option<String>

Custom / Standard Object Descriptions for example , Pet Object`s description

location_id: String

location’s id Required by the API.

primary_display_property: String

Primary property for the custom / standard Object. This would be used as primary data when rendering the UI. ‘custom_objects.{{object_key}} or business.{{object_key}} (for company)’ would be added as prefix by default for all the custom / standard objects Required by the API.

date_added: String

Date and time when the object was added Format: date-time (ISO-8601 string). Required by the API.

date_updated: String

Date and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API.

type_: Option<Value>

Object`s Type