pub struct ICustomObjectSchema {
pub id: String,
pub standard: bool,
pub key: String,
pub labels: CustomObjectLabelDto,
pub description: Option<String>,
pub location_id: String,
pub primary_display_property: String,
pub date_added: String,
pub date_updated: String,
pub type_: Option<Value>,
}objects only.Expand description
ICustomObjectSchema from the GoHighLevel OpenAPI spec.
Fields
id: Stringid of the custom / standard object schema Required by the API.
standard: boolfalse in case of custom objects and true in case of standard objects like contacts and opportunities Required by the API.
key: Stringkey that would be used to refer the custom / standard Object internally (lowercase + underscore_separated). For custom objects, ‘custom_objects.’ would be added as prefix by default Required by the API.
labels: CustomObjectLabelDtoThis is what your custom / standard object will be called. These labels will be used to display your custom object on the UI Required by the API.
description: Option<String>Custom / Standard Object Descriptions for example , Pet Object`s description
location_id: Stringlocation’s id Required by the API.
primary_display_property: StringPrimary property for the custom / standard Object. This would be used as primary data when rendering the UI. ‘custom_objects.{{object_key}} or business.{{object_key}} (for company)’ would be added as prefix by default for all the custom / standard objects Required by the API.
date_added: StringDate and time when the object was added Format: date-time (ISO-8601 string). Required by the API.
date_updated: StringDate and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API.
type_: Option<Value>Object`s Type