pub struct IRecordSchema {
pub id: String,
pub owner: Vec<String>,
pub followers: Vec<String>,
pub properties: String,
pub date_added: String,
pub date_updated: String,
}Available on crate feature
objects only.Expand description
IRecordSchema from the GoHighLevel OpenAPI spec.
Fields
id: Stringid of the record Required by the API.
owner: Vec<String>Owner (User’s id). Limited to 1 for now. Only Supported with custom objects Required by the API.
followers: Vec<String>Follower (User’s ids). Limited to 10 for now Required by the API.
properties: StringProperties of the record Required by the API.
date_added: StringDate and time when the object was added Format: date-time (ISO-8601 string). Required by the API.
date_updated: StringDate and time when the object was last updated Format: date-time (ISO-8601 string). Required by the API.