pub struct CreateCustomProvidersResponseSchema {Show 13 fields
pub name: String,
pub description: String,
pub payments_url: String,
pub query_url: String,
pub image_url: String,
pub id: String,
pub location_id: String,
pub marketplace_app_id: String,
pub payment_provider: Option<Value>,
pub deleted: bool,
pub created_at: String,
pub updated_at: String,
pub trace_id: Option<String>,
}payments only.Expand description
CreateCustomProvidersResponseSchema from the GoHighLevel OpenAPI spec.
Fields
name: StringThe name of the custom provider Required by the API.
description: StringDescription of payment gateway. Shown on the payments integrations page as subtext Required by the API.
payments_url: StringThis url will be loaded in iFrame to start a payment session. Required by the API.
query_url: StringThe url used for querying payments related events. Ex. verify, refund, subscription etc. Required by the API.
image_url: StringPublic image url for logo of the payment gateway displayed on the payments integrations page. Required by the API.
id: StringThe unique identifier for the custom provider. Required by the API.
location_id: StringLocation id Required by the API.
marketplace_app_id: StringThe application id of marketplace Required by the API.
payment_provider: Option<Value>Payment provider details.
deleted: boolWhether the config is deleted or not. true represents config is deleted Required by the API.
created_at: StringThe creation timestamp of the custom provider. Format: date-time (ISO-8601 string). Required by the API.
updated_at: StringThe last update timestamp of the custom provider. Format: date-time (ISO-8601 string). Required by the API.
trace_id: Option<String>Trace id of the custom provider.