CollectionSchema

Struct CollectionSchema 

pub struct CollectionSchema {
    pub id: Option<String>,
    pub alt_id: Option<String>,
    pub name: Option<String>,
    pub slug: Option<String>,
    pub image: Option<String>,
    pub seo: Option<CollectionSEODto>,
    pub created_at: Option<String>,
}
Available on crate feature products only.
CollectionSchema from the GoHighLevel OpenAPI spec.

Fields

id: Option<String>

The unique identifier for the collection Required by the API. (Optional here so responses that omit it still parse.)

alt_id: Option<String>

Location Id to which the collection is associated Required by the API. (Optional here so responses that omit it still parse.)

name: Option<String>

Name of the collection Required by the API. (Optional here so responses that omit it still parse.)

slug: Option<String>

Slug of the collection with which navigation is established. Special Characters and spacing is not allowed and should be unique Required by the API. (Optional here so responses that omit it still parse.)

image: Option<String>

The URL of the image that is going to be displayed as the collection Thumbnail Required by the API. (Optional here so responses that omit it still parse.)

seo: Option<CollectionSEODto>

The information which will be displayed in SEO previews Required by the API. (Optional here so responses that omit it still parse.)

created_at: Option<String>

Date at which the collection was created Required by the API. (Optional here so responses that omit it still parse.)