pub struct CollectionSchema {
pub id: String,
pub alt_id: String,
pub name: String,
pub slug: String,
pub image: String,
pub seo: CollectionSEODto,
pub created_at: String,
}Available on crate feature
products only.Expand description
CollectionSchema from the GoHighLevel OpenAPI spec.
Fields
id: StringThe unique identifier for the collection Required by the API.
alt_id: StringLocation Id to which the collection is associated Required by the API.
name: StringName of the collection Required by the API.
slug: StringSlug of the collection with which navigation is established. Special Characters and spacing is not allowed and should be unique Required by the API.
image: StringThe URL of the image that is going to be displayed as the collection Thumbnail Required by the API.
seo: CollectionSEODtoThe information which will be displayed in SEO previews Required by the API.
created_at: StringDate at which the collection was created Required by the API.