CreateShippingRateDto

Struct CreateShippingRateDto 

pub struct CreateShippingRateDto {
Show 13 fields pub alt_id: String, pub alt_type: String, pub name: String, pub description: Option<String>, pub currency: String, pub amount: f64, pub condition_type: String, pub min_condition: f64, pub max_condition: f64, pub is_carrier_rate: Option<bool>, pub shipping_carrier_id: String, pub percentage_of_rate_fee: Option<f64>, pub shipping_carrier_services: Vec<ShippingCarrierServiceDto>,
}
Available on crate feature store only.
CreateShippingRateDto from the GoHighLevel OpenAPI spec.

Fields

alt_id: String

Location Id or Agency Id Required by the API.

alt_type: String

Allowed values: location. Required by the API.

name: String

Name of the shipping zone Required by the API.

description: Option<String>

Delivery description

currency: String

The currency of the amount of the rate / handling fee Required by the API.

amount: f64

The amount of the shipping rate if it is normal rate (0 means free ). Fixed Handling fee if it is a carrier rate (it will add to the carrier rate). Required by the API.

condition_type: String

Type of condition to provide the conditional pricing Allowed values: none, price, weight. Required by the API.

min_condition: f64

Minimum condition for applying this price. set 0 or null if there is no minimum Required by the API.

max_condition: f64

Maximum condition for applying this price. set 0 or null if there is no maximum Required by the API.

is_carrier_rate: Option<bool>

is this a carrier rate

shipping_carrier_id: String

Shipping carrier id Required by the API.

percentage_of_rate_fee: Option<f64>

Percentage of rate fee if it is a carrier rate.

shipping_carrier_services: Vec<ShippingCarrierServiceDto>

An array of items