pub struct CreateOrUpdateServiceBookingResponseDTO {Show 16 fields
pub booking_id: String,
pub location_id: String,
pub contact_id: String,
pub service_location_id: String,
pub title: String,
pub start_time: String,
pub end_time: String,
pub services: Vec<ServiceDTO>,
pub timezone: String,
pub status: String,
pub deleted: bool,
pub date_added: String,
pub date_updated: String,
pub created_by: CreatedOrUpdatedBy,
pub meeting_location: Option<String>,
pub messages: Vec<Vec<Value>>,
}calendars only.Expand description
CreateOrUpdateServiceBookingResponseDTO from the GoHighLevel OpenAPI spec.
Fields
booking_id: StringBooking ID Required by the API.
location_id: StringLocation ID Required by the API.
contact_id: StringContact ID Required by the API.
service_location_id: StringService Location ID Required by the API.
title: StringService Booking Title Required by the API.
start_time: StringStart Time Required by the API.
end_time: StringEnd Time Required by the API.
services: Vec<ServiceDTO>Services Required by the API.
timezone: StringTimezone Required by the API.
status: StringStatus Required by the API.
deleted: boolTells if the booking is deleted Required by the API.
date_added: StringDate Added Required by the API.
date_updated: StringDate Updated Required by the API.
created_by: CreatedOrUpdatedByBooking booked by metadata Required by the API.
meeting_location: Option<String>Meeting Location (If service location is an ask the booker, then the meeting location is used for the booking)
messages: Vec<Vec<Value>>Optional informative or warning messages (e.g. meeting location ignored for non-ask-booker locations)