pub struct UpdateCustomFieldsDTO {
pub location_id: String,
pub name: Option<String>,
pub description: Option<String>,
pub placeholder: Option<String>,
pub show_in_forms: bool,
pub options: Vec<OptionDTO>,
pub accepted_formats: Option<String>,
pub max_file_limit: Option<f64>,
}custom-fields only.Expand description
UpdateCustomFieldsDTO from the GoHighLevel OpenAPI spec.
Fields
location_id: StringLocation Id Required by the API.
name: Option<String>Field name
description: Option<String>Description of the field
placeholder: Option<String>Placeholder text for the field
show_in_forms: boolWhether the field should be shown in forms Required by the API.
options: Vec<OptionDTO>Options for the field. Important: Providing options will completely replace the existing options array. You must include all existing options alongside any new options you wish to add. Removal of options is not supported through this update. Applicable only for SINGLE_OPTIONS, MULTIPLE_OPTIONS, RADIO, CHECKBOX, TEXTBOX_LIST types.
accepted_formats: Option<String>Allowed file formats for uploads. Options include: .pdf, .docx, .doc, .jpg, .jpeg, .png,
.gif, .csv, .xlsx, .xls, all
Allowed values: .pdf, .docx, .doc, .jpg, .jpeg, .png, .gif, .csv,
.xlsx, .xls, all.
max_file_limit: Option<f64>Maximum file limit for uploads. Applicable only for fields with a data type of FILE_UPLOAD.