pub struct QueueItemWithVariationsDTO {
pub id: Option<String>,
pub order: Option<f64>,
pub variations: Vec<VariationDTO>,
pub primary_image: Option<String>,
pub post_id: Option<String>,
pub post: Option<GetPostFormattedSchema>,
pub errors: Vec<String>,
pub scheduled_date_time: Option<String>,
pub scheduled_variation_index: Option<f64>,
pub is_skipped: Option<bool>,
pub current_variation: Option<f64>,
}Available on crate feature
social-planner only.Expand description
QueueItemWithVariationsDTO from the GoHighLevel OpenAPI spec.
Fields
id: Option<String>The unique identifier of the queue item.
order: Option<f64>The order of the item in the queue.
variations: Vec<VariationDTO>A list of content variations for the post.
primary_image: Option<String>The primary image URL for the post.
post_id: Option<String>The ID of the original post, if any.
post: Option<GetPostFormattedSchema>The formatted post data.
errors: Vec<String>List of errors associated with the queue item. Possible values: INVALID_USER_ID, PIXABAY_MEDIA.
scheduled_date_time: Option<String>The calculated date/time when this item is scheduled to be posted Format: date-time (ISO-8601 string).
scheduled_variation_index: Option<f64>The variation index that will be used when this item is posted
is_skipped: Option<bool>Indicates if this time slot is skipped and the post will not be published at this time
current_variation: Option<f64>The index of the current variation being used for this post