pub struct UpdateUserDto {Show 15 fields
pub first_name: Option<String>,
pub last_name: Option<String>,
pub email: Option<String>,
pub password: Option<String>,
pub phone: Option<String>,
pub type_: Option<String>,
pub role: Option<String>,
pub company_id: Option<String>,
pub location_ids: Vec<String>,
pub permissions: Option<PermissionsDto>,
pub scopes: Vec<String>,
pub scopes_assigned_to_only: Vec<String>,
pub profile_photo: Option<String>,
pub twilio_phone: Option<Value>,
pub platform_language: Option<String>,
}users only.Expand description
UpdateUserDto from the GoHighLevel OpenAPI spec.
Fields
first_name: Option<String>First name of the user
last_name: Option<String>Last name of the user
email: Option<String>Email update is no longer supported due to security reasons.
password: Option<String>New password for the user account. All passwords will be required to meet the following criteria: - Minimum 12 characters - At least one uppercase letter (A–Z) - At least one lowercase letter (a–z) - At least one number (0–9) - At least one special character (e.g., !, @, #, $)
phone: Option<String>Phone number of the user in E.164 format
type_: Option<String>User account type (account for sub-account users, agency for agency-level users)
role: Option<String>User role within the account (admin or user)
company_id: Option<String>Company/Agency Id. Required for Agency Level access
location_ids: Vec<String>List of sub-account location IDs the user should have access to
permissions: Option<PermissionsDto>User permissions controlling access to various features
scopes: Vec<String>Scopes allowed for users. Only scopes that have been passed will be enabled. If passed
empty all the scopes will be get disabled
Allowed values: campaigns.readonly, campaigns.write, calendars.readonly,
calendars/events.write, calendars/groups.write, calendars.write, contacts.write,
contacts/bulkActions.write, workflows.readonly, workflows.write, triggers.write,
funnels.write.
scopes_assigned_to_only: Vec<String>Assigned Scopes allowed for users. Only scopes that have been passed will be enabled. If
passed empty all the assigned scopes will be get disabled
Allowed values: campaigns.readonly, campaigns.write, calendars.readonly,
calendars/events.write, calendars/groups.write, calendars.write, contacts.write,
contacts/bulkActions.write, workflows.readonly, workflows.write, triggers.write,
funnels.write.
profile_photo: Option<String>URL of the user profile photo
twilio_phone: Option<Value>Per-location inbound Twilio number in E.164 format, keyed by location id (Call and Voicemail Inbound Number for direct Twilio, not LC Phone). Replacement semantics: if you send twilioPhone in the request body, the stored map is replaced entirely with this object (not merged). Any location id omitted from the object is removed from the saved map. Omit the twilioPhone property entirely to leave existing numbers unchanged. Send an empty object {} to clear all per-location numbers. To clear a single location only, set that location id to an empty string “”.
platform_language: Option<String>Platform language preference for the user
Allowed values: en_US, es, fr_CA, fr_FR, nl, de, pt_PT, pt_BR, it,
sv, da, fi.